@@ -14,7 +14,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/DUX/osi_vnodeops.c,v 1.1.1.6 2002/05/10 23:43:41 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/DUX/osi_vnodeops.c,v 1.1.1.7 2002/09/26 18:58:07 hartmans Exp $");
 
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
@@ -450,7 +450,7 @@ mp_afs_ubcrdwr(avc, uio, ioflag, cred)
 	return EISDIR;	/* can't read or write other things */
     }
     afs_BozonLock(&avc->pvnLock, avc);
-    osi_FlushPages(avc);	/* hold bozon lock, but not basic vnode lock */
+    osi_FlushPages(avc, cred);	/* hold bozon lock, but not basic vnode lock */
     ObtainWriteLock(&avc->lock,162);
     /* adjust parameters when appending files */
     if ((ioflag & IO_APPEND) && uio->uio_rw == UIO_WRITE)
@@ -718,7 +718,7 @@ mp_afs_mmap(avc, offset, map, addrp, len, prot, maxprot, flags, cred)
       return code;
     }
     afs_BozonLock(&avc->pvnLock, avc);
-    osi_FlushPages(avc);	/* ensure old pages are gone */
+    osi_FlushPages(avc, cred);	/* ensure old pages are gone */
     afs_BozonUnlock(&avc->pvnLock, avc);
     ObtainWriteLock(&avc->lock,166);
     avc->states |= CMAPPED;
