@@ -14,7 +14,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.1.1.12 2002/05/18 19:40:01 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.1.1.16 2003/07/30 17:08:10 hartmans Exp $");
 
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
@@ -25,37 +25,53 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/LINUX/osi_m
 
 char *crash_addr = 0; /* Induce an oops by writing here. */
 
-/* Lookup name and return vnode for same. */
-int osi_lookupname(char *aname, uio_seg_t seg, int followlink,
-	       vnode_t **dirvpp, struct dentry **dpp)
-{
 #if defined(AFS_LINUX24_ENV)
-    struct nameidata nd;
-#else
-    struct dentry *dp = NULL;
-#endif
+/* Lookup name and return vnode for same. */
+int osi_lookupname_internal(char *aname, uio_seg_t seg, int followlink,
+			    vnode_t **dirvpp, struct dentry **dpp, 
+			    struct nameidata *nd)
+{
     int code;
 
     code = ENOENT;
-#if defined(AFS_LINUX24_ENV)
     if (seg == AFS_UIOUSER) {
         code = followlink ?
-	    user_path_walk(aname, &nd) : user_path_walk_link(aname, &nd);
+	    user_path_walk(aname, nd) : user_path_walk_link(aname, nd);
     }
     else {
-        if (path_init(aname, followlink ? LOOKUP_FOLLOW : 0, &nd))
-	    code = path_walk(aname, &nd);
+	if (path_init(aname, followlink ? LOOKUP_FOLLOW : 0, nd))
+	    code = path_walk(aname, nd);
     }
 
     if (!code) {
-	if (nd.dentry->d_inode) {
-	    *dpp = dget(nd.dentry);
+	if (nd->dentry->d_inode) {
+	    *dpp = dget(nd->dentry);
 	    code = 0;
-	} else
+	} else {
 	    code = ENOENT;
-	path_release(&nd);
+	    path_release(nd);
+	}
     }
+    return code;
+}
+#endif
+
+int osi_lookupname(char *aname, uio_seg_t seg, int followlink,
+		   vnode_t **dirvpp, struct dentry **dpp)
+{
+#if defined(AFS_LINUX24_ENV)
+    struct nameidata nd;
+    int code = osi_lookupname_internal(aname, seg, followlink, dirvpp, dpp,
+				       &nd);
+    if (!code)
+	path_release(&nd);
+    
+    return (code);
 #else
+    struct dentry *dp = NULL;
+    int code;
+    
+    code = ENOENT;
     if (seg == AFS_UIOUSER) {
 	dp = followlink ? namei(aname) : lnamei(aname);
     }
@@ -71,9 +87,9 @@ int osi_lookupname(char *aname, uio_seg_t seg, int followlink,
 	else
 	    dput(dp);
     }
-#endif
 	    
     return code;
+#endif
 }
 
 /* Intialize cache device info and fragment size for disk cache partition. */
@@ -85,13 +101,15 @@ int osi_InitCacheInfo(char *aname)
     extern struct osi_dev cacheDev;
     extern afs_int32 afs_fsfragsize;
     extern struct super_block *afs_cacheSBp;
+    extern struct nameidata afs_cacheNd;
 
-    code = osi_lookupname(aname, AFS_UIOSYS, 1, NULL, &dp);
+    code = osi_lookupname_internal(aname, AFS_UIOSYS, 1, NULL, &dp, 
+				   &afs_cacheNd);
     if (code) return ENOENT;
 
     cacheInode = dp->d_inode->i_ino;
     cacheDev.dev = dp->d_inode->i_dev;
-    afs_fsfragsize = dp->d_inode->i_sb->s_blocksize;
+    afs_fsfragsize = dp->d_inode->i_sb->s_blocksize - 1;
     afs_cacheSBp = dp->d_inode->i_sb;
 
     dput(dp);
@@ -114,6 +132,7 @@ int osi_rdwr(int rw, struct osi_file *file, caddr_t addrp, size_t asize,
     KERNEL_SPACE_DECL;
     struct file *filp = &file->file;
     off_t offset = file->offset;
+    unsigned long savelim;
 
     /* Seek to the desired position. Return -1 on error. */
     if (filp->f_op->llseek) {
@@ -123,6 +142,9 @@ int osi_rdwr(int rw, struct osi_file *file, caddr_t addrp, size_t asize,
     else
 	filp->f_pos = offset;
 
+    savelim = current->rlim[RLIMIT_FSIZE].rlim_cur;
+    current->rlim[RLIMIT_FSIZE].rlim_cur = RLIM_INFINITY;
+
     /* Read/Write the data. */
     TO_USER_SPACE();
     if (rw == UIO_READ)
@@ -133,6 +155,8 @@ int osi_rdwr(int rw, struct osi_file *file, caddr_t addrp, size_t asize,
 	code = asize;
     TO_KERNEL_SPACE();
 
+    current->rlim[RLIMIT_FSIZE].rlim_cur = savelim;
+
     if (code >=0) {
 	*resid = asize - code;
 	return 0;
@@ -152,6 +176,10 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
     int code = 0;
     struct iovec *iov;
     int count;
+    unsigned long savelim;
+
+    savelim = current->rlim[RLIMIT_FSIZE].rlim_cur;
+    current->rlim[RLIMIT_FSIZE].rlim_cur = RLIM_INFINITY;
 
     if (uiop->uio_seg == AFS_UIOSYS)
 	TO_USER_SPACE();
@@ -165,7 +193,7 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
 	    uiop->uio_iovcnt--;
 	    continue;
 	}
-	
+
 	if (rw == UIO_READ)
 	    code = FOP_READ(filp, iov->iov_base, count);
 	else
@@ -186,6 +214,8 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
     if (uiop->uio_seg == AFS_UIOSYS)
 	TO_KERNEL_SPACE();
 
+    current->rlim[RLIMIT_FSIZE].rlim_cur = savelim;
+
     return code;
 }
 
@@ -329,7 +359,7 @@ void osi_linux_free_inode_pages(void)
 void osi_clear_inode(struct inode *ip)
 {
     cred_t *credp = crref();
-    struct vcache *vc = ITOAFS(ip);
+    struct vcache *vcp = ITOAFS(ip);
 
 #if defined(AFS_LINUX24_ENV)
     if (atomic_read(&ip->i_count) > 1)
@@ -338,15 +368,15 @@ void osi_clear_inode(struct inode *ip)
 #endif
         printf("afs_put_inode: ino %d (0x%x) has count %d\n", ip->i_ino, ip);
 
-    ObtainWriteLock(&vc->lock, 504);
-    afs_InactiveVCache(vc, credp);
-    ReleaseWriteLock(&vc->lock);
+    afs_InactiveVCache(vcp, credp);
+    ObtainWriteLock(&vcp->lock, 504);
 #if defined(AFS_LINUX24_ENV)
     atomic_set(&ip->i_count, 0);
 #else
     ip->i_count = 0;
 #endif
     ip->i_nlink = 0; /* iput checks this after calling this routine. */
+    ReleaseWriteLock(&vcp->lock);
     crfree(credp);
 }
 
@@ -432,18 +462,10 @@ void check_bad_parent(struct dentry *dp)
 struct task_struct *rxk_ListenerTask;
 
 void osi_linux_mask() {
-    spin_lock_irq(&current->sigmask_lock);
+    SIG_LOCK(current);
     sigfillset(&current->blocked);
-    recalc_sigpending(current);
-    spin_unlock_irq(&current->sigmask_lock);
-}
-
-void osi_linux_unmask() {
-    spin_lock_irq(&rxk_ListenerTask->sigmask_lock);
-    sigemptyset(&rxk_ListenerTask->blocked);
-    flush_signals(rxk_ListenerTask);
-    recalc_sigpending(rxk_ListenerTask);
-    spin_unlock_irq(&rxk_ListenerTask->sigmask_lock);
+    RECALC_SIGPENDING(current);
+    SIG_UNLOCK(current);
 }
 
 void osi_linux_rxkreg() {
