@@ -1,7 +1,7 @@
 /*
  * osi_sysctl.c: Linux sysctl interface to OpenAFS
  *
- * $Id: osi_sysctl.c,v 1.1.1.1 2002/05/10 23:44:08 hartmans Exp $
+ * $Id: osi_sysctl.c,v 1.1.1.2 2002/08/02 04:28:56 hartmans Exp $
  *
  * Written Jan 30, 2002 by Kris Van Hees (Sine Nomine Associates)
  */
@@ -34,6 +34,9 @@ static ctl_table afs_sysctl_table[] = {
         {3, "hm_retry_int",
          &hm_retry_int, sizeof(afs_int32), 0644, NULL,
          &proc_dointvec},
+        {4, "GCPAGs",
+         &afs_gcpags, sizeof(afs_int32), 0644, NULL,
+         &proc_dointvec},
 	{0}
 };
 
