@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/SOLARIS/osi_vnodeops.c,v 1.1.1.9 2002/05/10 23:44:14 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/SOLARIS/osi_vnodeops.c,v 1.1.1.11 2002/12/11 02:36:21 hartmans Exp $");
 
 #if	defined(AFS_SUN_ENV) || defined(AFS_SUN5_ENV)
 /*
@@ -81,6 +81,25 @@ AFS_TRYUP(lock)
 #endif
 
 
+/* Translate a faultcode_t as returned by some of the vm routines
+ * into a suitable errno value.
+ */
+static int
+afs_fc2errno(faultcode_t fc)
+{
+    switch (FC_CODE(fc)) {
+    case 0:
+	return 0;
+
+    case FC_OBJERR:
+	return FC_ERRNO(fc);
+
+    default:
+	return EIO;
+    }
+}
+
+
 extern struct as kas;	/* kernel addr space */
 extern unsigned char *afs_indexFlags;	       
 extern afs_lock_t afs_xdcache;		
@@ -1070,7 +1089,8 @@ struct AFS_UCRED *acred;
 	data = segmap_getmap(segkmap, AFSTOV(avc), pageBase);
 #endif
 #ifndef	AFS_SUN5_ENV
-	code = as_fault(&kas, data+pageOffset, tsize, F_SOFTLOCK, mode);
+	code = afs_fc2errno(as_fault(&kas, data+pageOffset, tsize,
+				     F_SOFTLOCK, mode));
 	if (code == 0) {
 	    AFS_UIOMOVE(data+pageOffset, tsize, arw, auio, code);
 	    as_fault(&kas, data+pageOffset, tsize, F_SOFTUNLOCK, mode);
@@ -1131,7 +1151,8 @@ struct AFS_UCRED *acred;
 		AFS_GUNLOCK();
 	    }
 	    if (!created)
-		code = segmap_fault(kas.a_hat, segkmap, raddr, rsize, F_SOFTLOCK, mode);
+		code = afs_fc2errno(segmap_fault(kas.a_hat, segkmap, raddr,
+						 rsize, F_SOFTLOCK, mode));
 	}
 	if (code == 0) {
 	    AFS_UIOMOVE(data+pageOffset, tsize, arw, auio, code);
@@ -1914,12 +1935,17 @@ void afs_inactive(struct vcache *avc, struct AFS_UCRED *acred)
         mutex_exit(&vp->v_lock);
         return;
     }	
-    mutex_exit(&vp->v_lock);    
+    mutex_exit(&vp->v_lock);
+
     /*
-     * Solaris calls VOP_OPEN on exec, but isn't very diligent about calling
-     * VOP_CLOSE when executable exits.
+     * Solaris calls VOP_OPEN on exec, but doesn't call VOP_CLOSE when
+     * the executable exits.  So we clean up the open count here.
+     *
+     * Only do this for mvstat 0 vnodes: when using fakestat, we can't
+     * lose the open count for volume roots (mvstat 2), even though they
+     * will get VOP_INACTIVE'd when released by afs_PutFakeStat().
      */
-    if (avc->opens > 0 && !(avc->states & CCore))
+    if (avc->opens > 0 && avc->mvstat == 0 && !(avc->states & CCore))
 	avc->opens = avc->execsOrWriters = 0;
 
     afs_InactiveVCache(avc, acred);
