@@ -5,6 +5,8 @@
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
+ *
+ * Portions Copyright (c) 2003 Apple Computer, Inc.
  */
 
 /*
@@ -21,7 +23,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_attrs.c,v 1.1.1.8 2002/05/10 23:44:19 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_attrs.c,v 1.1.1.13 2004/01/10 20:52:57 hartmans Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -33,24 +35,31 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_v
 extern afs_rwlock_t afs_xcbhash;
 struct afs_exporter *afs_nfsexporter;
 extern struct vcache *afs_globalVp;
+#if defined(AFS_HPUX110_ENV)
+extern struct vfs *afs_globalVFS;
+#endif
 
 /* copy out attributes from cache entry */
 afs_CopyOutAttrs(avc, attrs)
     register struct vattr *attrs;
-    register struct vcache *avc; {
+    register struct vcache *avc;
+{
     register struct volume *tvp;
     register struct cell *tcell;
     register afs_int32 i;
+    int fakedir = 0;
 
     AFS_STATCNT(afs_CopyOutAttrs);
+    if (afs_fakestat_enable && avc->mvstat == 1)
+	fakedir = 1;
 #if	defined(AFS_MACH_ENV )
-    attrs->va_mode = vType(avc) | (avc->m.Mode&~VFMT);
+    attrs->va_mode = fakedir ? VDIR | 0755 : vType(avc) | (avc->m.Mode&~VFMT);
 #else /* AFS_MACH_ENV */
-    attrs->va_type = vType(avc);
+    attrs->va_type = fakedir ? VDIR : vType(avc);
 #if defined(AFS_SGI_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_SUN5_ENV)
-    attrs->va_mode = (mode_t)(avc->m.Mode & 0xffff);
+    attrs->va_mode = fakedir ? 0755 : (mode_t)(avc->m.Mode & 0xffff);
 #else
-    attrs->va_mode = avc->m.Mode;
+    attrs->va_mode = fakedir ? VDIR | 0755 : avc->m.Mode;
 #endif
 #endif /* AFS_MACH_ENV */
 
@@ -60,8 +69,31 @@ afs_CopyOutAttrs(avc, attrs)
 	if (tcell && (tcell->states & CNoSUID))
 	    attrs->va_mode &= ~(VSUID|VSGID);
     }
-    attrs->va_uid = avc->m.Owner;
-    attrs->va_gid = avc->m.Group;   /* yeah! */
+#if defined(AFS_DARWIN_ENV)
+    {
+	extern u_int32_t afs_darwin_realmodes;
+	if (!afs_darwin_realmodes) {
+	    /* Mac OS X uses the mode bits to determine whether a file or
+	     * directory is accessible, and believes them, even though under
+	     * AFS they're almost assuredly wrong, especially if the local uid
+	     * does not match the AFS ID.  So we set the mode bits
+	     * conservatively.
+	     */
+	    if (S_ISDIR(attrs->va_mode)) {
+	      /* all access bits need to be set for directories, since even
+	       * a mode 0 directory can still be used normally.
+	       */
+	      attrs->va_mode |= ACCESSPERMS;
+	    } else {
+	      /* for other files, replicate the user bits to group and other */
+	      mode_t ubits = (attrs->va_mode & S_IRWXU) >> 6;
+	      attrs->va_mode |= ubits | (ubits << 3);
+	    }
+	}
+    }
+#endif /* AFS_DARWIN_ENV */
+    attrs->va_uid = fakedir ? 0 : avc->m.Owner;
+    attrs->va_gid = fakedir ? 0 : avc->m.Group;   /* yeah! */
 #if	defined(AFS_SUN56_ENV)
     attrs->va_fsid = avc->v.v_vfsp->vfs_fsid.val[0];
 #else
@@ -72,7 +104,11 @@ afs_CopyOutAttrs(avc, attrs)
 #ifdef AFS_OSF_ENV
     attrs->va_fsid = avc->v.v_mount->m_stat.f_fsid.val[0]; 
 #else
+#ifdef AFS_DARWIN70_ENV
+    attrs->va_fsid = avc->v.v_mount->mnt_stat.f_fsid.val[0]; 
+#else /* ! AFS_DARWIN70_ENV */
     attrs->va_fsid = 1;
+#endif /* AFS_DARWIN70_ENV */
 #endif
 #endif
 #endif /* AFS_SUN56_ENV */
@@ -90,10 +126,10 @@ afs_CopyOutAttrs(avc, attrs)
     }
     else attrs->va_nodeid = avc->fid.Fid.Vnode + (avc->fid.Fid.Volume << 16);
     attrs->va_nodeid &= 0x7fffffff;	/* Saber C hates negative inode #s! */
-    attrs->va_nlink = avc->m.LinkCount;
-    attrs->va_size = avc->m.Length;
+    attrs->va_nlink = fakedir ? 100 : avc->m.LinkCount;
+    attrs->va_size = fakedir ? 4096 : avc->m.Length;
     attrs->va_atime.tv_sec = attrs->va_mtime.tv_sec = attrs->va_ctime.tv_sec =
-	avc->m.Date;
+	fakedir ? 0 : (int)avc->m.Date;
     /* set microseconds to be dataversion # so that we approximate NFS-style
      * use of mtime as a dataversion #.  We take it mod 512K because
      * microseconds *must* be less than a million, and 512K is the biggest
@@ -101,7 +137,17 @@ afs_CopyOutAttrs(avc, attrs)
      * anyway, so the difference between 512K and 1000000 shouldn't matter
      * much, and "&" is a lot faster than "%".
      */
-#if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+    /* nfs on these systems puts an 0 in nsec and stores the nfs usec (aka 
+       dataversion) in va_gen */
+
+    attrs->va_atime.tv_nsec = attrs->va_mtime.tv_nsec =
+	attrs->va_ctime.tv_nsec =0;
+    attrs->va_blocksize = PAGESIZE;		/* XXX Was 8192 XXX */
+    attrs->va_gen = hgetlo(avc->m.DataVersion);
+    attrs->va_flags = 0;
+#else
+#if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV) 
     attrs->va_atime.tv_nsec = attrs->va_mtime.tv_nsec =
 	attrs->va_ctime.tv_nsec =
 	    (hgetlo(avc->m.DataVersion) & 0x7ffff) * 1000;
@@ -116,6 +162,7 @@ afs_CopyOutAttrs(avc, attrs)
 	    (hgetlo(avc->m.DataVersion) & 0x7ffff);
     attrs->va_blocksize = PAGESIZE;		/* XXX Was 8192 XXX */
 #endif
+#endif
 #ifdef AFS_DEC_ENV
     /* Have to use real device #s in Ultrix, since that's how FS type is
      * encoded.  If rdev doesn't match Ultrix equivalent of statfs's rdev, then
@@ -128,18 +175,23 @@ afs_CopyOutAttrs(avc, attrs)
 #else 
     attrs->va_rdev = 1;
 #endif
+
+#if defined(AFS_HPUX110_ENV)
+	if (afs_globalVFS) attrs->va_fstype = afs_globalVFS->vfs_mtype;
+#endif
+
     /*
      * Below return 0 (and not 1) blocks if the file is zero length. This conforms
      * better with the other filesystems that do return 0.	
      */
-#if   defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV)
+#if   defined(AFS_OSF_ENV)
 #ifdef	va_size_rsv
     attrs->va_size_rsv = 0;
 #endif
 /* XXX do this */
 /*    attrs->va_gen = avc->m.DataVersion;*/
     attrs->va_flags = 0;
-#endif	/* AFS_OSF_ENV || AFS_DARWIN_ENV */
+#endif	/* AFS_OSF_ENV */
 
 #if !defined(AFS_OSF_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
 #if !defined(AFS_HPUX_ENV)
@@ -192,12 +244,35 @@ afs_getattr(OSI_VC_ARG(avc), attrs, acred)
     afs_Trace2(afs_iclSetp, CM_TRACE_GETATTR, ICL_TYPE_POINTER, avc, 
 	       ICL_TYPE_INT32, avc->m.Length);
 
+    if (afs_fakestat_enable && avc->mvstat == 1) {
+	struct afs_fakestat_state fakestat;
+
+	code = afs_InitReq(&treq, acred);
+	if (code) return code;
+	afs_InitFakeStat(&fakestat);
+	code = afs_TryEvalFakeStat(&avc, &fakestat, &treq);
+	if (code) {
+	    afs_PutFakeStat(&fakestat);
+	    return code;
+	}
+
+	code = afs_CopyOutAttrs(avc, attrs);
+	afs_PutFakeStat(&fakestat);
+	return code;
+    }
+
 #if defined(AFS_SUN5_ENV)
     if (flags & ATTR_HINT) {
        code = afs_CopyOutAttrs(avc, attrs);
        return code;
     }
 #endif
+#if defined(AFS_DARWIN_ENV)
+    if (avc->states & CUBCinit) {
+       code = afs_CopyOutAttrs(avc, attrs);
+       return code;
+    }
+#endif
 
 #if defined(AFS_SUN_ENV) || defined(AFS_ALPHA_ENV) || defined(AFS_SUN5_ENV)
     afs_BozonLock(&avc->pvnLock, avc);
@@ -392,12 +467,19 @@ afs_setattr(avc, attrs, acred)
     struct vrequest treq;
     struct AFSStoreStatus astat;
     register afs_int32 code;
+    struct afs_fakestat_state fakestate;
     OSI_VC_CONVERT(avc)
 
     AFS_STATCNT(afs_setattr);
     afs_Trace2(afs_iclSetp, CM_TRACE_SETATTR, ICL_TYPE_POINTER, avc, 
 	       ICL_TYPE_INT32, avc->m.Length);
     if (code = afs_InitReq(&treq, acred)) return code;
+
+    afs_InitFakeStat(&fakestate);
+    code = afs_EvalFakeStat(&avc, &fakestate, &treq);
+    if (code)
+      goto done;
+
     if (avc->states & CRO) {
 	code=EROFS;
 	goto done;
@@ -516,6 +598,7 @@ afs_setattr(avc, attrs, acred)
     AFS_RWUNLOCK((vnode_t *)avc, VRWLOCK_WRITE);
 #endif
 done:
+    afs_PutFakeStat(&fakestate);
     code = afs_CheckCode(code, &treq, 15);
     return code;
 }
