@@ -22,7 +22,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_remove.c,v 1.1.1.7 2002/05/10 23:44:24 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_remove.c,v 1.1.1.9 2002/08/02 04:29:03 hartmans Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -226,6 +226,7 @@ afs_remove(OSI_VC_ARG(adp), aname, acred)
     afs_int32 offset, len;
     struct AFSFetchStatus OutDirStatus;
     struct AFSVolSync tsync;
+    struct afs_fakestat_state fakestate;
     XSTATS_DECLS
     OSI_VC_CONVERT(adp)
 
@@ -237,15 +238,6 @@ afs_remove(OSI_VC_ARG(adp), aname, acred)
     tvc = (struct vcache *)ndp->ni_vp;  /* should never be null */
 #endif
 
-    /* Check if this is dynroot */
-    if (afs_IsDynroot(adp)) {
-#ifdef  AFS_OSF_ENV
-        afs_PutVCache(adp, 0);
-        afs_PutVCache(tvc, 0);
-#endif
-	return afs_DynrootVOPRemove(adp, acred, aname);
-    }
-
     if (code = afs_InitReq(&treq, acred)) {
 #ifdef  AFS_OSF_ENV
         afs_PutVCache(adp, 0);
@@ -253,7 +245,30 @@ afs_remove(OSI_VC_ARG(adp), aname, acred)
 #endif
       return code;
     }
+
+    afs_InitFakeStat(&fakestate);
+    code = afs_EvalFakeStat(&adp, &fakestate, &treq);
+    if (code) {
+	afs_PutFakeStat(&fakestate);
+#ifdef  AFS_OSF_ENV
+	afs_PutVCache(adp, 0);
+	afs_PutVCache(tvc, 0);
+#endif
+	return code;
+    }
+
+    /* Check if this is dynroot */
+    if (afs_IsDynroot(adp)) {
+	code = afs_DynrootVOPRemove(adp, acred, aname);
+	afs_PutFakeStat(&fakestate);
+#ifdef  AFS_OSF_ENV
+	afs_PutVCache(adp, 0);
+	afs_PutVCache(tvc, 0);
+#endif
+	return code;
+    }
     if (strlen(aname) > AFSNAMEMAX) {
+	afs_PutFakeStat(&fakestate);
 #ifdef  AFS_OSF_ENV
 	afs_PutVCache(adp, 0);
 	afs_PutVCache(tvc, 0);
@@ -267,13 +282,15 @@ tagain:
     if (code) {
 	afs_PutVCache(adp, 0);
 	afs_PutVCache(tvc, 0);
+	afs_PutFakeStat(&fakestate);
 	return afs_CheckCode(code, &treq, 22);
     }
 #else	/* AFS_OSF_ENV */
     tvc = (struct vcache *) 0;
     if (code) {
-      code = afs_CheckCode(code, &treq, 23);
-      return code;
+	code = afs_CheckCode(code, &treq, 23);
+	afs_PutFakeStat(&fakestate);
+	return code;
     }
 #endif
 
@@ -286,6 +303,7 @@ tagain:
         afs_PutVCache(tvc, 0);
 #endif
         code = EROFS;
+	afs_PutFakeStat(&fakestate);
 	return code;
     }
 
@@ -356,7 +374,7 @@ tagain:
 	char *unlname = newname();
 
 	ReleaseWriteLock(&adp->lock);
-	code = afsrename(adp, aname, adp, unlname, acred);
+	code = afsrename(adp, aname, adp, unlname, acred, &treq);
 	Tnam1 = unlname;
 	if (!code) {
 	    tvc->mvid = (struct VenusFid *)unlname;
@@ -378,6 +396,7 @@ tagain:
 #ifdef	AFS_OSF_ENV
     afs_PutVCache(adp, WRITE_LOCK);
 #endif	/* AFS_OSF_ENV */
+    afs_PutFakeStat(&fakestate);
     return code;
 }
 
