@@ -17,7 +17,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_rename.c,v 1.1.1.5 2002/05/10 23:44:25 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_rename.c,v 1.1.1.6 2002/08/02 04:29:03 hartmans Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -31,11 +31,12 @@ extern afs_rwlock_t afs_xcbhash;
 /* Note that we don't set CDirty here, this is OK because the rename
  * RPC is called synchronously. */
 
-afsrename(aodp, aname1, andp, aname2, acred)
-    register struct vcache *aodp, *andp;
+afsrename(aodp, aname1, andp, aname2, acred, areq)
+    struct vcache *aodp, *andp;
     char *aname1, *aname2;
-    struct AFS_UCRED *acred; {
-    struct vrequest treq;
+    struct AFS_UCRED *acred;
+    struct vrequest *areq;
+{
     register struct conn *tc;
     register afs_int32 code;
     afs_int32 returnCode;
@@ -53,8 +54,6 @@ afsrename(aodp, aname1, andp, aname2, acred)
 	       ICL_TYPE_STRING, aname1, ICL_TYPE_POINTER, andp,
 	       ICL_TYPE_STRING, aname2);
 
-    if (code = afs_InitReq(&treq, acred)) return code;
-
     if (strlen(aname1) > AFSNAMEMAX || strlen(aname2) > AFSNAMEMAX) {
 	code = ENAMETOOLONG;
 	goto done;
@@ -62,9 +61,9 @@ afsrename(aodp, aname1, andp, aname2, acred)
 
     /* verify the latest versions of the stat cache entries */
 tagain:
-    code = afs_VerifyVCache(aodp, &treq);
+    code = afs_VerifyVCache(aodp, areq);
     if (code) goto done;
-    code = afs_VerifyVCache(andp, &treq);
+    code = afs_VerifyVCache(andp, areq);
     if (code) goto done;
     
     /* lock in appropriate order, after some checks */
@@ -107,7 +106,7 @@ tagain:
      * fileFid in order to handle ".." invalidation at the very end.
      */
     code = 0;
-    tdc1 = afs_GetDCache(aodp, 0, &treq, &offset, &len, 0);
+    tdc1 = afs_GetDCache(aodp, 0, areq, &offset, &len, 0);
     if (!tdc1) {
 	code = ENOENT;
     }
@@ -135,7 +134,7 @@ tagain:
 
     /* locks are now set, proceed to do the real work */
     do {
-	tc = afs_Conn(&aodp->fid, &treq, SHARED_LOCK);
+	tc = afs_Conn(&aodp->fid, areq, SHARED_LOCK);
 	if (tc) {
           XSTATS_START_TIME(AFS_STATS_FS_RPCIDX_RENAME);
 #ifdef RX_ENABLE_LOCKS
@@ -151,7 +150,7 @@ tagain:
 	} else code = -1;
 
     } while
-	(afs_Analyze(tc, code, &andp->fid, &treq,
+	(afs_Analyze(tc, code, &andp->fid, areq,
 		     AFS_STATS_FS_RPCIDX_RENAME, SHARED_LOCK, (struct cell *)0));
 
     returnCode = code;	    /* remember for later */
@@ -265,11 +264,11 @@ tagain:
 	unlinkFid.Cell = aodp->fid.Cell;
 	tvc = (struct vcache *)0;
 	if (!unlinkFid.Fid.Unique) {
-	    tvc = afs_LookupVCache(&unlinkFid, &treq, (afs_int32 *)0, WRITE_LOCK,
+	    tvc = afs_LookupVCache(&unlinkFid, areq, (afs_int32 *)0, WRITE_LOCK,
 				   aodp, aname1);
 	}
 	if (!tvc) /* lookup failed or wasn't called */
-	   tvc = afs_GetVCache(&unlinkFid, &treq, (afs_int32 *)0,
+	   tvc = afs_GetVCache(&unlinkFid, areq, (afs_int32 *)0,
 			       (struct vcache*)0, WRITE_LOCK);
 
 	if (tvc) {
@@ -303,9 +302,9 @@ tagain:
 	fileFid.Fid.Volume = aodp->fid.Fid.Volume;
 	fileFid.Cell = aodp->fid.Cell;
 	if (!fileFid.Fid.Unique)
-	    tvc = afs_LookupVCache(&fileFid, &treq, (afs_int32 *)0, WRITE_LOCK, andp, aname2);
+	    tvc = afs_LookupVCache(&fileFid, areq, (afs_int32 *)0, WRITE_LOCK, andp, aname2);
 	else
-	    tvc = afs_GetVCache(&fileFid, &treq, (afs_int32 *)0,
+	    tvc = afs_GetVCache(&fileFid, areq, (afs_int32 *)0,
 				(struct vcache*)0, WRITE_LOCK);
 	if (tvc && (vType(tvc) == VDIR)) {
 	    ObtainWriteLock(&tvc->lock,152);
@@ -327,16 +326,15 @@ tagain:
     }
     code = returnCode;
 done:
-    code = afs_CheckCode(code, &treq, 25);
     return code;
 }
 
 #ifdef	AFS_OSF_ENV
 afs_rename(fndp, tndp)
     struct nameidata *fndp, *tndp; {
-    register struct vcache *aodp = VTOAFS(fndp->ni_dvp);
+    struct vcache *aodp = VTOAFS(fndp->ni_dvp);
     char *aname1 = fndp->ni_dent.d_name;
-    register struct vcache *andp = VTOAFS(tndp->ni_dvp);
+    struct vcache *andp = VTOAFS(tndp->ni_dvp);
     char *aname2 = tndp->ni_dent.d_name;
     struct ucred *acred = tndp->ni_cred;
 #else	/* AFS_OSF_ENV */
@@ -347,14 +345,28 @@ afs_rename(OSI_VC_ARG(aodp), aname1, andp, aname2, npnp, acred)
 afs_rename(OSI_VC_ARG(aodp), aname1, andp, aname2, acred)
 #endif
     OSI_VC_DECL(aodp);
-    register struct vcache *andp;
+    struct vcache *andp;
     char *aname1, *aname2;
     struct AFS_UCRED *acred; {
 #endif
     register afs_int32 code;
+    struct afs_fakestat_state ofakestate;
+    struct afs_fakestat_state nfakestate;
+    struct vrequest treq;
     OSI_VC_CONVERT(aodp)
 
-    code = afsrename(aodp, aname1, andp, aname2, acred);
+    code = afs_InitReq(&treq, acred);
+    if (code) return code;
+    afs_InitFakeStat(&ofakestate);
+    afs_InitFakeStat(&nfakestate);
+    code = afs_EvalFakeStat(&aodp, &ofakestate, &treq);
+    if (code) goto done;
+    code = afs_EvalFakeStat(&andp, &nfakestate, &treq);
+    if (code) goto done;
+    code = afsrename(aodp, aname1, andp, aname2, acred, &treq);
+done:
+    afs_PutFakeStat(&ofakestate);
+    afs_PutFakeStat(&nfakestate);
 #ifdef	AFS_OSF_ENV
     AFS_RELE(tndp->ni_dvp);
     if (tndp->ni_vp != NULL) {
@@ -363,5 +375,6 @@ afs_rename(OSI_VC_ARG(aodp), aname1, andp, aname2, acred)
     AFS_RELE(fndp->ni_dvp);
     AFS_RELE(fndp->ni_vp);
 #endif	/* AFS_OSF_ENV */
+    code = afs_CheckCode(code, &treq, 25);
     return code;
 }
