@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/afs_call.c,v 1.1.1.12 2002/05/10 23:43:08 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/afs_call.c,v 1.1.1.17 2003/07/30 17:07:58 hartmans Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -21,7 +21,7 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/afs_call.c,
 #ifdef AFS_SGI62_ENV
 #include "../h/hashing.h"
 #endif
-#if !defined(AFS_HPUX110_ENV)
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_DARWIN60_ENV)
 #include "netinet/in_var.h"
 #endif
 #endif /* !defined(UKERNEL) */
@@ -61,9 +61,10 @@ simple_lock_data_t afs_global_lock;
 #elif defined(AFS_DARWIN_ENV)
 struct lock__bsd__ afs_global_lock;
 #elif defined(AFS_FBSD_ENV)
-struct simplelock afs_global_lock;
+struct lock afs_global_lock;
+struct proc *afs_global_owner;
 #endif
-#if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV)
 thread_t afs_global_owner;
 #endif /* AFS_OSF_ENV */
 
@@ -82,6 +83,7 @@ static int afs_CacheInit_Done = 0;
 static int afs_Go_Done = 0;
 extern struct interfaceAddr afs_cb_interface;
 static int afs_RX_Running = 0;
+static int afs_InitSetup_done = 0;
 
 static int
 Afscall_icl(long opcode, long p1, long p2, long p3, long p4, long *retval);
@@ -98,6 +100,9 @@ static int afs_InitSetup(int preallocs)
     extern void afs_InitStats();
     int code;
 
+    if (afs_InitSetup_done)
+	return;
+
 #ifndef AFS_NOSTATS
     /*
      * Set up all the AFS statistics variables.  This should be done
@@ -120,13 +125,188 @@ static int afs_InitSetup(int preallocs)
     /* resource init creates the services */
     afs_ResourceInit(preallocs);
 
+    afs_InitSetup_done = 1;
+    afs_osi_Wakeup(&afs_InitSetup_done);
+
     return code;
 }
+#if defined(AFS_LINUX24_ENV) && defined(COMPLETION_H_EXISTS)
+struct afsd_thread_info {
+    unsigned long parm;
+    struct completion *complete;
+};
+
+static int afsd_thread(void *rock) {
+     struct afsd_thread_info  *arg=rock;
+     unsigned long parm=arg->parm;
+#ifdef SYS_SETPRIORITY_EXPORTED
+     int (*sys_setpriority)(int,int,int) = sys_call_table[__NR_setpriority];
+#endif
+     daemonize(); /* doesn't do much, since we were forked from keventd, but
+                     does call mm_release, which wakes up our parent (since it
+                     used CLONE_VFORK) */
+     reparent_to_init();
+     afs_osi_MaskSignals();
+     switch (parm) {
+     case AFSOP_START_RXCALLBACK:
+          sprintf(current->comm, "afs_cbstart");
+          AFS_GLOCK();
+          complete(arg->complete);
+          afs_CB_Running = 1;     
+          while (afs_RX_Running != 2)
+               afs_osi_Sleep(&afs_RX_Running);
+          sprintf(current->comm, "afs_callback");
+          afs_RXCallBackServer();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     case AFSOP_START_AFS:
+          sprintf(current->comm, "afs_afsstart");
+          AFS_GLOCK();
+          complete(arg->complete);
+          AFS_Running = 1;
+          while (afs_initState < AFSOP_START_AFS) 
+               afs_osi_Sleep(&afs_initState);
+          DInit(AFS_MINBUFFERS);          
+          afs_initState = AFSOP_START_BKG;
+          afs_osi_Wakeup(&afs_initState);
+          sprintf(current->comm, "afsd");
+          afs_Daemon();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     case AFSOP_START_BKG:
+          sprintf(current->comm, "afs_bkgstart");
+          AFS_GLOCK();
+          complete(arg->complete);
+          while (afs_initState < AFSOP_START_BKG) 
+               afs_osi_Sleep(&afs_initState);
+          if (afs_initState < AFSOP_GO) {
+               afs_initState = AFSOP_GO;
+               afs_osi_Wakeup(&afs_initState);
+          }
+          sprintf(current->comm, "afs_background");          
+          afs_BackgroundDaemon();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     case AFSOP_START_TRUNCDAEMON:
+          sprintf(current->comm, "afs_trimstart");
+          AFS_GLOCK();
+          complete(arg->complete);
+          while (afs_initState < AFSOP_GO) 
+               afs_osi_Sleep(&afs_initState);
+          sprintf(current->comm, "afs_cachetrim");
+          afs_CacheTruncateDaemon();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     case AFSOP_START_CS:
+          sprintf(current->comm, "afs_checkserver");
+          AFS_GLOCK();
+          complete(arg->complete);
+          afs_CheckServerDaemon();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     case AFSOP_RXEVENT_DAEMON:
+          sprintf(current->comm, "afs_evtstart");
+#ifdef SYS_SETPRIORITY_EXPORTED
+        sys_setpriority(PRIO_PROCESS,0,-10);
+#else
+#ifdef CURRENT_INCLUDES_NICE
+        current->nice=-10;
+#endif
+#endif
+          AFS_GLOCK();
+          complete(arg->complete);
+          while (afs_initState < AFSOP_START_BKG) 
+               afs_osi_Sleep(&afs_initState);
+          sprintf(current->comm, "afs_rxevent");
+          afs_rxevent_daemon();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     case AFSOP_RXLISTENER_DAEMON:
+          sprintf(current->comm, "afs_lsnstart");
+#ifdef SYS_SETPRIORITY_EXPORTED
+        sys_setpriority(PRIO_PROCESS,0,-10);
+#else
+#ifdef CURRENT_INCLUDES_NICE
+        current->nice=-10;
+#endif
+#endif
+          AFS_GLOCK();
+          complete(arg->complete);
+          afs_initState = AFSOP_START_AFS;
+          afs_osi_Wakeup(&afs_initState);
+          afs_RX_Running = 2;
+          afs_osi_Wakeup(&afs_RX_Running);
+          afs_osi_RxkRegister();
+          sprintf(current->comm, "afs_rxlistener");
+          rxk_Listener();
+          AFS_GUNLOCK();
+          complete_and_exit(0,0);
+          break;
+     default:
+          printf("Unknown op %d in StartDaemon()\n");
+          break;
+     }
+     return 0;
+}
+
+void afsd_launcher(void *rock) {
+     if (!kernel_thread(afsd_thread,rock, CLONE_VFORK|SIGCHLD))
+	printf("kernel_thread failed. afs startup will not complete\n");
+}
+
+void afs_DaemonOp(long parm, long parm2, long parm3, long parm4, long parm5, 
+             long parm6) 
+{
+     int code;
+     DECLARE_COMPLETION(c);
+     struct tq_struct tq;
+     struct afsd_thread_info info;     
+     if (parm == AFSOP_START_RXCALLBACK) {
+          if (afs_CB_Running) return;
+     } else if (parm == AFSOP_RXLISTENER_DAEMON) {
+          if (afs_RX_Running) return;
+          afs_RX_Running=1;
+          code = afs_InitSetup(parm2);
+          if (parm3) {
+               rx_enablePeerRPCStats();
+          }
+          if (parm4) {
+               rx_enableProcessRPCStats();
+          }
+          if (code)
+               return;
+     } else if (parm == AFSOP_START_AFS) {
+          if (AFS_Running) return;
+     } /* other functions don't need setup in the parent */     
+     info.complete=&c;
+     info.parm=parm;
+     tq.sync=0;
+     INIT_LIST_HEAD(&tq.list);
+     tq.routine=afsd_launcher;
+     tq.data=&info;
+     schedule_task(&tq);
+     AFS_GUNLOCK();
+     /* we need to wait cause we passed stack pointers around.... */
+     wait_for_completion(&c);
+     AFS_GLOCK();
+}
+#endif
 
 afs_syscall_call(parm, parm2, parm3, parm4, parm5, parm6)
 long parm, parm2, parm3, parm4, parm5, parm6;
 {
     afs_int32 code = 0;
+#if defined(AFS_SGI61_ENV) || defined(AFS_SUN57_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+    size_t bufferSize;	
+#else /* AFS_SGI61_ENV */
+    u_int bufferSize;	
+#endif /* AFS_SGI61_ENV */
 
     AFS_STATCNT(afs_syscall_call);
 #ifdef	AFS_SUN5_ENV
@@ -151,6 +331,12 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 #endif
     }
     AFS_GLOCK();
+#if defined(AFS_LINUX24_ENV) && defined(COMPLETION_H_EXISTS) && !defined(UKERNEL)
+    if (parm < AFSOP_ADDCELL || parm == AFSOP_RXEVENT_DAEMON
+         || parm == AFSOP_RXLISTENER_DAEMON) {
+         afs_DaemonOp(parm,parm2,parm3,parm4,parm5,parm6);
+    }
+#else
     if (parm == AFSOP_START_RXCALLBACK) {
 	if (afs_CB_Running) goto out;
 	afs_CB_Running = 1;
@@ -204,21 +390,11 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 #endif
     else if (parm == AFSOP_START_AFS) {
 	/* afs daemon */
-	afs_int32 temp;
-
 	if (AFS_Running) goto out;
 	AFS_Running = 1;
 	while (afs_initState < AFSOP_START_AFS) 
 	    afs_osi_Sleep(&afs_initState);
 
-#if defined(AFS_SUN_ENV) || defined(AFS_SGI_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
-	temp = AFS_MINBUFFERS;  /* Should fix this soon */
-#else
-	temp = ((afs_bufferpages * NBPG)>>11);	/* number of 2k buffers we could get from all of the buffer space */
-	temp = temp>>2;	/* don't take more than 25% (our magic parameter) */
-	if (temp < AFS_MINBUFFERS) temp = AFS_MINBUFFERS;   /* although we really should have this many */
-#endif
-	DInit(temp);
 	afs_initState = AFSOP_START_BKG;
 	afs_osi_Wakeup(&afs_initState);
 	afs_osi_Invisible();
@@ -278,13 +454,32 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 #endif
     }
 #endif	
+#endif
+    else if (parm == AFSOP_BASIC_INIT) {
+	afs_int32 temp;
+
+	while (!afs_InitSetup_done)
+	    afs_osi_Sleep(&afs_InitSetup_done);
+
+#if defined(AFS_SUN_ENV) || defined(AFS_SGI_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+	temp = AFS_MINBUFFERS;  /* Should fix this soon */
+#else
+	/* number of 2k buffers we could get from all of the buffer space */
+	temp = ((afs_bufferpages * NBPG)>>11);
+	temp = temp>>2;	/* don't take more than 25% (our magic parameter) */
+	if (temp < AFS_MINBUFFERS)
+	    temp = AFS_MINBUFFERS; /* though we really should have this many */
+#endif
+	DInit(temp);
+	afs_rootFid.Fid.Volume = 0;
+	code = 0;
+    }
     else if (parm == AFSOP_ADDCELL) {
 	/* add a cell.  Parameter 2 is 8 hosts (in net order),  parm 3 is the null-terminated
 	 name.  Parameter 4 is the length of the name, including the null.  Parm 5 is the
 	 home cell flag (0x1 bit) and the nosuid flag (0x2 bit) */
 	struct afsop_cell tcell;
 
-	while (afs_initState < AFSOP_START_BKG) afs_osi_Sleep(&afs_initState);
 	AFS_COPYIN((char *)parm2, (char *)tcell.hosts, sizeof(tcell.hosts), code);
 	if (!code) {
 	    if (parm4 > sizeof(tcell.cellName)) 
@@ -293,22 +488,19 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 		AFS_COPYIN((char *)parm3, tcell.cellName, parm4, code);
 		if (!code) 
 		    afs_NewCell(tcell.cellName, tcell.hosts, parm5,
-				(char *)0, (u_short)0, (u_short)0, (int)0);
+			        NULL, 0, 0, 0);
 	    }
 	}
     } else if (parm == AFSOP_ADDCELL2) {
 	struct afsop_cell tcell;
 	char *tbuffer = osi_AllocSmallSpace(AFS_SMALLOCSIZ), *lcnamep = 0;
 	char *tbuffer1 = osi_AllocSmallSpace(AFS_SMALLOCSIZ), *cnamep = 0;
-#if defined(AFS_SGI61_ENV) || defined(AFS_SUN57_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
-	size_t bufferSize;	
-#else /* AFS_SGI61_ENV */
-	u_int bufferSize;	
-#endif /* AFS_SGI61_ENV */
 	int cflags = parm4;
 
-	/* wait for basic init */
+#if 0
+	/* wait for basic init - XXX can't find any reason we need this? */
 	while (afs_initState < AFSOP_START_BKG) afs_osi_Sleep(&afs_initState);
+#endif
 
 	AFS_COPYIN((char *)parm2, (char *)tcell.hosts, sizeof(tcell.hosts), code);
 	if (!code) {
@@ -323,7 +515,7 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 		}
 		if (!code)
 		    afs_NewCell(tbuffer1, tcell.hosts, cflags, 
-				lcnamep, (u_short)0, (u_short)0, (int)0);
+				lcnamep, 0, 0, 0);
 	    }
 	}
 	osi_FreeSmallSpace(tbuffer);
@@ -335,34 +527,33 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 	 * parm2 is the alias name
 	 * parm3 is the real cell name
 	 */
-#if defined(AFS_SGI61_ENV) || defined(AFS_SUN57_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
-	size_t bufferSize;
-#else /* AFS_SGI61_ENV */
-	u_int bufferSize;	
-#endif /* AFS_SGI61_ENV */
 	char *aliasName = osi_AllocSmallSpace(AFS_SMALLOCSIZ);
 	char *cellName = osi_AllocSmallSpace(AFS_SMALLOCSIZ);
 
 	AFS_COPYINSTR((char *)parm2, aliasName, AFS_SMALLOCSIZ, &bufferSize, code);
 	if (!code) AFS_COPYINSTR((char *)parm3, cellName, AFS_SMALLOCSIZ, &bufferSize, code);
-	if (!code) afs_NewCell(aliasName,	/* new entry name */
-			       0,		/* host list */
-			       CAlias,		/* flags */
-			       (char *) 0,	/* linked cell */
-			       0, 0,		/* fs & vl ports */
-			       0,		/* timeout */
-			       cellName);	/* real cell name */
+	if (!code) afs_NewCellAlias(aliasName, cellName);
 
 	osi_FreeSmallSpace(aliasName);
 	osi_FreeSmallSpace(cellName);
     }
+    else if (parm == AFSOP_SET_THISCELL) {
+	/*
+	 * Call arguments:
+	 * parm2 is the primary cell name
+	 */
+	char *cell = osi_AllocSmallSpace(AFS_SMALLOCSIZ);
+
+	AFS_COPYINSTR((char *) parm2, cell, AFS_SMALLOCSIZ, &bufferSize, code);
+	if (!code)
+	    afs_SetPrimaryCell(cell);
+	osi_FreeSmallSpace(cell);
+    }
     else if (parm == AFSOP_CACHEINIT) {
 	struct afs_cacheParams cparms;
 
 	if (afs_CacheInit_Done) goto out;
 
-	/* wait for basic init */
-	while (afs_initState < AFSOP_START_BKG) afs_osi_Sleep(&afs_initState);
 	AFS_COPYIN((char *)parm2, (caddr_t) &cparms, sizeof(cparms), code);
 	if (code) {
 #if	defined(AFS_SUN5_ENV) || defined(AFS_OSF_ENV) || defined (AFS_SGI64_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
@@ -411,12 +602,6 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 	code = afs_InitCacheFile((char *) 0, ainode);
     }
     else if (parm == AFSOP_ROOTVOLUME) {
-#if defined(AFS_SGI61_ENV) || defined(AFS_SUN57_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
-	size_t bufferSize;
-#else /* AFS_SGI61_ENV */
-	u_int bufferSize;
-#endif /* AFS_SGI61_ENV */
-
 	/* wait for basic init */
 	while (afs_initState < AFSOP_START_BKG) afs_osi_Sleep(&afs_initState);
 
@@ -426,29 +611,31 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 	}
 	else code = 0;
     }
-    else if (parm == AFSOP_CACHEFILE || parm == AFSOP_CACHEINFO ||
-	      parm == AFSOP_VOLUMEINFO || parm == AFSOP_AFSLOG) {
+    else if (parm == AFSOP_CACHEFILE ||
+	     parm == AFSOP_CACHEINFO ||
+	     parm == AFSOP_VOLUMEINFO ||
+	     parm == AFSOP_AFSLOG ||
+	     parm == AFSOP_CELLINFO) {
 	char *tbuffer = osi_AllocSmallSpace(AFS_SMALLOCSIZ);
-#if defined(AFS_SGI61_ENV) || defined(AFS_SUN57_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
-	size_t bufferSize;
-#else /* AFS_SGI61_ENV */
-	u_int bufferSize;
-#endif /* AFS_SGI61_ENV */
 
-	/* wait for basic init */
-	while (afs_initState < AFSOP_START_BKG) afs_osi_Sleep(&afs_initState);
 	code = 0;
-	AFS_COPYINSTR((char *)parm2, tbuffer, AFS_SMALLOCSIZ, &bufferSize, code);
+	AFS_COPYINSTR((char *) parm2, tbuffer, AFS_SMALLOCSIZ,
+		      &bufferSize, code);
 	if (code) {
 	    osi_FreeSmallSpace(tbuffer);
 	    goto out;
 	}
 	if (!code) {
-	    tbuffer[AFS_SMALLOCSIZ-1] = 0;	/* null-terminate the name */
-	    /* we now have the cache dir copied in.  Call the cache init routines */
-	    if (parm == AFSOP_CACHEFILE) code = afs_InitCacheFile(tbuffer, 0);
-	    else if (parm == AFSOP_CACHEINFO) code = afs_InitCacheInfo(tbuffer);
-	    else if (parm == AFSOP_VOLUMEINFO) code = afs_InitVolumeInfo(tbuffer);
+	    tbuffer[AFS_SMALLOCSIZ-1] = '\0';	/* null-terminate the name */
+	    /* We have the cache dir copied in.  Call the cache init routine */
+	    if (parm == AFSOP_CACHEFILE)
+		code = afs_InitCacheFile(tbuffer, 0);
+	    else if (parm == AFSOP_CACHEINFO)
+		code = afs_InitCacheInfo(tbuffer);
+	    else if (parm == AFSOP_VOLUMEINFO)
+		code = afs_InitVolumeInfo(tbuffer);
+	    else if (parm == AFSOP_CELLINFO)
+		code = afs_InitCellInfo(tbuffer);
 	}
 	osi_FreeSmallSpace(tbuffer);
     }
@@ -544,11 +731,13 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 #endif
 	afs_cold_shutdown = 0;
 	if (parm == 1) afs_cold_shutdown = 1;
-	if (afs_globalVFS != 0) {
+#ifndef AFS_DARWIN_ENV
+        if (afs_globalVFS != 0) {
 	    afs_warn("AFS isn't unmounted yet! Call aborted\n");
-	    code = EACCES;
-	}
-	afs_shutdown();
+            code = EACCES;
+        } else
+#endif
+            afs_shutdown();
     }
 
 #if	! defined(AFS_HPUX90_ENV) || defined(AFS_HPUX100_ENV)
@@ -619,11 +808,19 @@ long parm, parm2, parm3, parm4, parm5, parm6;
       }
 #else /* AFS_USERSPACE_IP_ADDR */
       struct ifnet *tifnp;
+#ifdef AFS_DARWIN60_ENV
+      struct ifaddr *tifadp = (struct ifaddr *) 0;
+#else
       struct in_ifaddr *tifadp = (struct in_ifaddr *) 0;
+#endif
       extern struct ifnet *rxi_FindIfnet();
       tifnp = rxi_FindIfnet(parm2, &tifadp);  /* make iterative */
       if (tifnp && tifadp) {
+#ifdef AFS_DARWIN60_ENV
+	 mask = ((struct sockaddr_in *)tifadp->ifa_netmask)->sin_addr.s_addr;
+#else
 	 mask = tifadp->ia_subnetmask;
+#endif
       } else {
 	 code = -1;
       }
@@ -646,7 +843,7 @@ long parm, parm2, parm3, parm4, parm5, parm6;
 	AFS_COPYIN((afs_int32 *)parm2, cellname, cellLen, code);
 	AFS_COPYIN((afs_int32 *)parm3, kmsg, kmsgLen, code);
 	if (!code) {
-	    code = afs_AfsdbHandler(cellname, cellLen, kmsg);
+	    code = afs_AFSDBHandler(cellname, cellLen, kmsg);
 	    if (*cellname == 1) *cellname = 0;
 	    if (code == -2) {	/* Shutting down? */
 		*cellname = 1;
@@ -661,6 +858,10 @@ long parm, parm2, parm3, parm4, parm5, parm6;
     else if (parm == AFSOP_SET_DYNROOT) {
 	code = afs_SetDynrootEnable(parm2);
     }
+    else if (parm == AFSOP_SET_FAKESTAT) {
+    	afs_fakestat_enable = parm2;
+    	code = 0;
+    }
     else
       code = EINVAL;
 
@@ -892,11 +1093,13 @@ copyin_iparam(caddr_t cmarg, struct iparam *dst)
 
 #ifdef AFS_SPARC64_LINUX24_ENV
 	if (current->thread.flags & SPARC_FLAG_32BIT) 
-#elif AFS_SPARC64_LINUX20_ENV
+#elif defined(AFS_SPARC64_LINUX20_ENV)
 	if (current->tss.flags & SPARC_FLAG_32BIT) 
+#elif defined(AFS_AMD64_LINUX20_ENV)
+	if (current->thread.flags & THREAD_IA32) 
 #else
 #error Not done for this linux version
-#endif /* AFS_SPARC64_LINUX20_ENV */
+#endif 
 	{
 		AFS_COPYIN(cmarg, (caddr_t) &dst32, sizeof dst32, code);
 		if (!code)
@@ -973,7 +1176,7 @@ struct afssysargs {
     long parm6; /* not actually used - should be removed */
 };
 /* Linux system calls only set up for 5 arguments. */
-asmlinkage int afs_syscall(long syscall, long parm1, long parm2, long parm3,
+asmlinkage long afs_syscall(long syscall, long parm1, long parm2, long parm3,
 			   long parm4)
 {
     struct afssysargs args, *uap = &args;
@@ -1266,7 +1469,7 @@ afs_shutdown()
     }
 #ifdef AFS_AFSDB_ENV
     afs_warn("AFSDB... ");
-    afs_StopAfsdb();
+    afs_StopAFSDB();
     while (afs_termState == AFSOP_STOP_AFSDB)
 	afs_osi_Sleep(&afs_termState);
 #endif
