@@ -16,7 +16,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/afs_init.c,v 1.1.1.6 2001/07/14 22:19:21 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/afs_init.c,v 1.1.1.10 2003/04/13 19:02:36 hartmans Exp $");
 
 #include "../afs/stds.h"
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
@@ -39,6 +39,7 @@ extern afs_rwlock_t afs_xaxs;
 extern afs_rwlock_t afs_xvolume;
 extern afs_rwlock_t afs_xuser;
 extern afs_rwlock_t afs_xserver;
+extern afs_rwlock_t afs_xsrvAddr;
 #ifndef AFS_AIX41_ENV
 extern afs_lock_t osi_fsplock;
 #endif
@@ -89,6 +90,7 @@ extern afs_int32 usedihint;
 
 /* afs_server.c */
 extern afs_int32 afs_setTime;
+extern afs_rwlock_t afs_xsrvAddr;
 
 /* Imported functions. */
 extern struct rx_securityClass *rxnull_NewServerSecurityObject();
@@ -102,7 +104,7 @@ extern afs_lock_t afs_ftf;
 /* Exported variables */
 struct osi_dev cacheDev;           /*Cache device*/
 afs_int32 cacheInfoModTime;			/*Last time cache info modified*/
-#if defined(AFS_OSF_ENV) || defined(AFS_DEC_ENV) || defined(AFS_DARWIN_ENV)
+#if defined(AFS_OSF_ENV) || defined(AFS_DEC_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
 struct mount *afs_cacheVfsp=0;
 #elif defined(AFS_LINUX20_ENV)
 struct super_block *afs_cacheSBp = 0;
@@ -310,36 +312,50 @@ afs_ComputeCacheParms()
  *	WARNING: Data will be written to this file over time by AFS.
  */
 
-afs_InitVolumeInfo(afile)
-    register char *afile;
-
-{ /*afs_InitVolumeInfo*/
-
+static int LookupInodeByPath(char *filename, ino_t *inode)
+{
     afs_int32 code;
-    struct osi_file *tfile;
-    struct vnode *filevp;
-    struct fcache fce;
-
-    AFS_STATCNT(afs_InitVolumeInfo);
+  
 #ifdef AFS_LINUX22_ENV
-    {
-	struct dentry *dp;
-	code = gop_lookupname(afile, AFS_UIOSYS, 0, (struct vnode **) 0, &dp);
-	if (code) return ENOENT;
-	fce.inode = volumeInode = dp->d_inode->i_ino;
-	dput(dp);
-    }
+    struct dentry *dp;
+    code = gop_lookupname(filename, AFS_UIOSYS, 0, NULL, &dp);
+    if (code) return code;
+    *inode = dp->d_inode->i_ino;
+    dput(dp);
 #else
-    code = gop_lookupname(afile, AFS_UIOSYS, 0, (struct vnode **) 0, &filevp);
-    if (code) return ENOENT;
-    fce.inode = volumeInode = afs_vnodeToInumber(filevp);
+    struct vnode *filevp;
+    code = gop_lookupname(filename, AFS_UIOSYS, 0, NULL, &filevp);
+    if (code) return code;
+    *inode = afs_vnodeToInumber(filevp);
 #ifdef AFS_DEC_ENV
     grele(filevp);
 #else
     AFS_RELE((struct vnode *)filevp);
 #endif
 #endif /* AFS_LINUX22_ENV */
-    tfile = afs_CFileOpen(fce.inode);
+ 
+    return 0;
+ }
+ 
+int afs_InitCellInfo(char *afile)
+{
+    ino_t inode;
+    int code;
+    
+    code = LookupInodeByPath(afile, &inode);
+    return afs_cellname_init(inode, code);
+}
+ 
+int afs_InitVolumeInfo(char *afile)
+{
+    int code;
+    struct osi_file *tfile;
+    struct vnode *filevp;
+    
+    AFS_STATCNT(afs_InitVolumeInfo);
+    code = LookupInodeByPath(afile, &volumeInode);
+    if (code) return code;
+    tfile = afs_CFileOpen(volumeInode);
     afs_CFileTruncate(tfile, 0);
     afs_CFileClose(tfile);
     return 0;
@@ -439,11 +455,15 @@ afs_InitCacheInfo(afile)
 	      TO_KERNEL_SPACE();
 	  }
 #else
-#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV)
         if (!VFS_STATFS(filevp->v_mount, &st, current_proc()))
+#else 
+#if defined(AFS_FBSD_ENV)
+        if (!VFS_STATFS(filevp->v_mount, &st, curproc))
 #else 
 	if (!VFS_STATFS(filevp->v_vfsp, &st))  
-#endif /* AFS_DARWIN_ENV || AFS_FBSD_ENV */
+#endif /* AFS_FBSD_ENV */
+#endif /* AFS_DARWIN_ENV */
 #endif /* AFS_LINUX20_ENV */
 #endif /* AIX41 */
 #endif /* OSF */
@@ -515,8 +535,9 @@ afs_ResourceInit(preallocs)
     AFS_STATCNT(afs_ResourceInit);
     RWLOCK_INIT(&afs_xuser, "afs_xuser");
     RWLOCK_INIT(&afs_xvolume, "afs_xvolume");
-    RWLOCK_INIT(&afs_xcell, "afs_xcell");
     RWLOCK_INIT(&afs_xserver, "afs_xserver");
+    RWLOCK_INIT(&afs_xsrvAddr, "afs_xsrvAddr");
+    RWLOCK_INIT(&afs_icl_lock, "afs_icl_lock");
     RWLOCK_INIT(&afs_xinterface, "afs_xinterface");
     LOCK_INIT(&afs_puttofileLock, "afs_puttofileLock");
 #ifndef	AFS_AIX32_ENV
@@ -525,6 +546,7 @@ afs_ResourceInit(preallocs)
     LOCK_INIT(&osi_flplock, "osi_flplock");
     RWLOCK_INIT(&afs_xconn, "afs_xconn");
 
+    afs_CellInit();
     afs_InitCBQueue(1);  /* initialize callback queues */
 
     if (afs_resourceinit_flag == 0) {
@@ -536,7 +558,6 @@ afs_ResourceInit(preallocs)
 	afs_sysname = afs_sysnamelist[0];
 	strcpy(afs_sysname, SYS_NAME);
 	afs_sysnamecount = 1;
-	QInit(&CellLRU);	
 #if	defined(AFS_AIX32_ENV) || defined(AFS_HPUX_ENV)
     {  extern afs_int32 afs_preallocs;
 
@@ -695,8 +716,8 @@ shutdown_cache()
     cacheInfoModTime = 0;
 
     afs_fsfragsize = 1023;
-    bzero((char *)&afs_stats_cmperf, sizeof(afs_stats_cmperf));
-    bzero((char *)&cacheDev, sizeof(struct osi_dev));
+    memset((char *)&afs_stats_cmperf, 0, sizeof(afs_stats_cmperf));
+    memset((char *)&cacheDev, 0, sizeof(struct osi_dev));
     osi_dnlc_shutdown();
   }
 } /*shutdown_cache*/
@@ -742,19 +763,6 @@ void shutdown_AFS()
     AFS_STATCNT(shutdown_AFS);
     if (afs_cold_shutdown) {
       afs_resourceinit_flag = 0; 
-      /* 
-       * Free Cells table allocations 
-       */
-      { 
-	struct cell *tc;
-	register struct afs_q *cq, *tq;
-	for (cq = CellLRU.next; cq != &CellLRU; cq = tq) {
-	    tc = QTOC(cq); tq = QNext(cq);
-	    if (tc->cellName)
-		afs_osi_Free(tc->cellName, strlen(tc->cellName)+1);
-	    afs_osi_Free(tc, sizeof(struct cell));
-	}
-      }
       /* 
        * Free Volumes table allocations 
        */
@@ -851,19 +859,16 @@ void shutdown_AFS()
       afs_sysname = 0;
       afs_sysnamecount = 0;
       afs_marinerHost = 0;
-      QInit(&CellLRU);      
       afs_setTimeHost = (struct server *)0;
       afs_volCounter = 1;
       afs_waitForever = afs_waitForeverCount = 0;
-      afs_cellindex = 0;
-      afs_nextCellNum = 0x100;
       afs_FVIndex = -1;
       afs_server = (struct rx_service *)0;
       RWLOCK_INIT(&afs_xconn, "afs_xconn");
-      bzero((char *)&afs_rootFid, sizeof(struct VenusFid));
+      memset((char *)&afs_rootFid, 0, sizeof(struct VenusFid));
       RWLOCK_INIT(&afs_xuser, "afs_xuser");
       RWLOCK_INIT(&afs_xvolume, "afs_xvolume"), RWLOCK_INIT(&afs_xcell, "afs_xcell");
-      RWLOCK_INIT(&afs_xserver, "afs_xserver"), LOCK_INIT(&afs_puttofileLock, "afs_puttofileLock");
+      shutdown_cell();
     }
     
 } /*shutdown_AFS*/
