@@ -13,7 +13,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/afs_segments.c,v 1.1.1.5 2001/09/11 14:24:45 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/afs_segments.c,v 1.1.1.8 2004/01/10 20:52:47 hartmans Exp $");
 
 #include "../afs/sysincludes.h" /*Standard vendor system headers*/
 #include "../afs/afsincludes.h" /*AFS-based standard headers*/
@@ -182,13 +182,13 @@ afs_StoreAllSegments(avc, areq, sync)
     dcList = (struct dcache **) osi_AllocLargeSpace(AFS_LRALLOCSIZ);
     afs_Trace2(afs_iclSetp, CM_TRACE_STOREALL, ICL_TYPE_POINTER, avc,
 	       ICL_TYPE_INT32, avc->m.Length);
-#ifndef AFS_AIX32_ENV
+#if !defined(AFS_AIX32_ENV) && !defined(AFS_SGI65_ENV)
     /* In the aix vm implementation we need to do the vm_writep even
      * on the memcache case since that's we adjust the file's size
      * and finish flushing partial vm pages.
      */
     if (cacheDiskType != AFS_FCACHE_TYPE_MEM) 
-#endif /* AFS_AIX32_ENV */
+#endif /* !AFS_AIX32_ENV && !AFS_SGI65_ENV */
     {
 	/* If we're not diskless, reading a file may stress the VM
 	 * system enough to cause a pageout, and this vnode would be
@@ -284,6 +284,8 @@ afs_StoreAllSegments(avc, areq, sync)
       if (j) {
 	static afs_uint32 lp1 = 10000, lp2 = 10000;
 	struct AFSStoreStatus InStatus;
+	struct AFSFetchStatus OutStatus;
+	int doProcessFS = 0;
 	afs_uint32 base, bytes, nchunks;
 	int nomore;
 	unsigned int first;
@@ -475,7 +477,6 @@ afs_StoreAllSegments(avc, areq, sync)
                      * one which has the writing bit turned on. */
 		}
 		if (!code) {
-		    struct AFSFetchStatus OutStatus;
 		    struct AFSVolSync tsync;
 #ifdef RX_ENABLE_LOCKS
 		    AFS_GUNLOCK();
@@ -486,19 +487,7 @@ afs_StoreAllSegments(avc, areq, sync)
 #endif /* RX_ENABLE_LOCKS */
 		    hadd32(newDV, 1);
 		    XSTATS_END_TIME;
-      
-		    /* Now copy out return params */
-		    UpgradeSToWLock(&avc->lock,28);    /* keep out others for a while */
-		    if (!code) {  /* must wait til RPC completes to be sure of this info */
-			afs_ProcessFS(avc, &OutStatus, areq);
-			/* Keep last (max) size of file on server to see if
-			 * we need to call afs_StoreMini to extend the file.
-			 */
-			if (!moredata)
-			    maxStoredLength = OutStatus.Length;
-
-		    }
-		    ConvertWToSLock(&avc->lock);
+		    if (!code) doProcessFS = 1; /* Flag to run afs_ProcessFS() later on */		    
 		}
 		if (tcall) {
 #ifdef RX_ENABLE_LOCKS
@@ -538,6 +527,19 @@ afs_StoreAllSegments(avc, areq, sync)
 		lockedPutDCache(tdc);
 	    }
 
+	    if (doProcessFS) {
+		/* Now copy out return params */
+		UpgradeSToWLock(&avc->lock,28);    /* keep out others for a while */
+		afs_ProcessFS(avc, &OutStatus, areq);
+		/* Keep last (max) size of file on server to see if
+		 * we need to call afs_StoreMini to extend the file.
+		 */
+		if (!moredata)
+		    maxStoredLength = OutStatus.Length;
+		ConvertWToSLock(&avc->lock);
+		doProcessFS = 0;
+	    }
+
 	    if (code) {
 		for (j++; j<=high; j++)
 		    if ( dcList[j] )
