@@ -9,8 +9,21 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <ctype.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afsd/vsys.c,v 1.1.1.4 2001/07/14 22:20:07 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afsd/vsys.c,v 1.1.1.5 2001/10/14 18:03:38 hartmans Exp $");
 
 #include <afs/afs_args.h>
 
@@ -46,4 +59,5 @@ main (argc, argv)
     }
     code = syscall(AFS_SYSCALL, parms[0], parms[1], parms[2], parms[3], parms[4], parms[5]);
     printf("code %d\n", code);
+    return 0;
 }
