@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/cellconfig.c,v 1.1.1.10 2001/09/20 06:12:38 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/auth/cellconfig.c,v 1.1.1.14 2003/07/30 17:11:21 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
@@ -24,6 +24,9 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/cellconfig
 #include <sys/utime.h>
 #include <io.h>
 #include <WINNT/afssw.h>
+#ifdef AFS_AFSDB_ENV
+#include <cm_dns.h>
+#endif /* AFS_AFSDB_ENV */
 #else
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -35,17 +38,33 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/cellconfig
 #include <resolv.h>
 #endif /* AFS_AFSDB_ENV */
 #endif /* AFS_NT40_ENV */
+#include <afs/afsint.h>
 #include <errno.h>
 #include <ctype.h>
 #include <time.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #endif /* UKERNEL */
 #include <afs/afsutil.h>
 #include "cellconfig.h"
 #include "keys.h"
 
+#ifndef T_AFSDB
+#define T_AFSDB 18  /* per RFC1183 section 1 */
+#endif
+
 static ParseHostLine();
 static ParseCellLine();
 static afsconf_OpenInternal();
@@ -53,19 +72,19 @@ static afsconf_CloseInternal();
 static afsconf_Reopen();
 
 static struct afsconf_servPair serviceTable [] = {
-    "afs",	7000,
-    "afscb",	7001,
-    "afsprot",	7002,
-    "afsvldb",	7003,
-    "afskauth",	7004,
-    "afsvol",	7005,
-    "afserror",	7006,
-    "afsnanny",	7007,
-    "afsupdate",7008,
-    "afsrmtsys",7009,
-    "afsres",   7010,   /* residency database for MR-AFS */
-    "afsremio", 7011,   /* remote I/O interface for MR-AFS */
-    0, 0		/* insert new services before this spot */
+    { "afs",       7000, },
+    { "afscb",     7001, },
+    { "afsprot",   7002, },
+    { "afsvldb",   7003, },
+    { "afskauth",  7004, },
+    { "afsvol",    7005, },
+    { "afserror",  7006, },
+    { "afsnanny",  7007, },
+    { "afsupdate", 7008, },
+    { "afsrmtsys", 7009, },
+    { "afsres",    7010, },  /* residency database for MR-AFS */
+    { "afsremio",  7011, },  /* remote I/O interface for MR-AFS */
+    { 0, 0 }		     /* insert new services before this spot */
 };
 
 /*
@@ -106,7 +125,7 @@ char *abuffer; {
     register int tc;
 
     tp = abuffer;
-    while (tc = *tp) {
+    while ((tc = *tp)) {
 	if (!isspace(tc)) break;
 	tp++;
     }
@@ -342,6 +361,7 @@ char clones[];
     FILE *tf;
     register char *tp, *bp;
     register struct afsconf_entry *curEntry;
+    struct afsconf_aliasentry *curAlias;
     register afs_int32 code;
     afs_int32 i;
     char tbuffer[256], tbuf1[256];
@@ -353,9 +373,12 @@ char clones[];
 #else
     i = GetCellUnix(adir);
 #endif
+
+#ifndef AFS_FREELANCE_CLIENT  /* no local cell not fatal in freelance */
     if (i) {
 	return i;
     }
+#endif
 
     /* now parse the individual lines */
     curEntry = 0;
@@ -451,7 +474,45 @@ char clones[];
 	curEntry->next = adir->entries;
 	adir->entries = curEntry;
     }
-    
+
+    /* Read in the alias list */
+    strcompose(tbuffer, 256, adir->name, "/", AFSDIR_CELLALIAS_FILE, NULL);
+
+    tf = fopen(tbuffer, "r");
+    while (tf) {
+	char *aliasPtr;
+
+	tp = fgets(tbuffer, sizeof(tbuffer), tf);
+	if (!tp) break;
+	TrimLine(tbuffer);  /* remove white space */
+
+	if (tbuffer[0] == '\0' ||
+	    tbuffer[0] == '\n' ||
+	    tbuffer[0] == '#') continue;	/* empty line */
+
+	tp = tbuffer;
+	while (tp[0] != '\0' && tp[0] != ' ' && tp[0] != '\t') tp++;
+	if (tp[0] == '\0') continue;		/* invalid line */
+
+	while (tp[0] != '\0' && (tp[0] == ' ' || tp[0] == '\t')) 0[tp++] = '\0';
+	if (tp[0] == '\0') continue;		/* invalid line */
+
+	aliasPtr = tp;
+	while (tp[0] != '\0' && tp[0] != ' ' && tp[0] != '\t' &&
+	       tp[0] != '\r' && tp[0] != '\n') tp++;
+	tp[0] = '\0';
+
+	curAlias = malloc(sizeof(*curAlias));
+	memset(curAlias, 0, sizeof(*curAlias));
+
+	strcpy(curAlias->aliasInfo.aliasName, aliasPtr);
+	strcpy(curAlias->aliasInfo.realName, tbuffer);
+
+	curAlias->next = adir->alias_entries;
+	adir->alias_entries = curAlias;
+    }
+
+    if (tf != NULL) fclose(tf);
     /* now read the fs keys, if possible */
     adir->keystr = (struct afsconf_keys *) 0;
     afsconf_IntGetKeys(adir);
@@ -483,6 +544,9 @@ static ParseHostLine(aline, addr, aname, aclone)
     if (code != 5) return AFSCONF_SYNTAX;
     addr->sin_family = AF_INET;
     addr->sin_port = 0;
+#ifdef STRUCT_SOCKADDR_HAS_SA_LEN
+    addr->sin_len = sizeof(struct sockaddr_in);
+#endif
     tp = (char *) &addr->sin_addr;
     *tp++ = c1;
     *tp++ = c2;
@@ -527,6 +591,28 @@ char *arock; {
     return 0;
 }
 
+/* call aproc(entry, arock, adir) for all cell aliases.
+ * Proc must return 0, or we'll stop early and return the code it returns
+ */
+afsconf_CellAliasApply(adir, aproc, arock)
+    struct afsconf_dir *adir;
+    int (*aproc)();
+    char *arock;
+{
+    register struct afsconf_aliasentry *tde;
+    register afs_int32 code;
+    LOCK_GLOBAL_MUTEX
+    for(tde=adir->alias_entries; tde; tde=tde->next) {
+	code = (*aproc)(&tde->aliasInfo, arock, adir);
+	if (code) {
+	    UNLOCK_GLOBAL_MUTEX
+	    return code;
+	}
+    }
+    UNLOCK_GLOBAL_MUTEX
+    return 0;
+}
+
 afs_int32 afsconf_SawCell = 0;
 
 afsconf_GetExtendedCellInfo(adir, acellName, aservice, acellInfo, clones)
@@ -553,6 +639,7 @@ afsconf_GetExtendedCellInfo(adir, acellName, aservice, acellInfo, clones)
 }
 
 #ifdef AFS_AFSDB_ENV
+#if !defined(AFS_NT40_ENV)
 afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
     char *acellName;
     char *aservice;
@@ -563,6 +650,7 @@ afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
     size_t len;
     unsigned char answer[1024];
     unsigned char *p;
+    char realCellName[256];
     char host[256];
     int server_num = 0;
     int minttl = 0;
@@ -582,7 +670,6 @@ afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
     code = dn_expand(answer, answer + len, p, host, sizeof(host));
     if (code < 0)
 	return AFSCONF_NOTFOUND;
-    strncpy(acellInfo->name, host, sizeof(acellInfo->name));
 
     p += code + QFIXEDSZ;	/* Skip name */
 
@@ -606,6 +693,15 @@ afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
 	    short afsdb_type;
 
 	    afsdb_type = (p[0] << 8) | p[1];
+	    if (afsdb_type == 1) {
+		/*
+		 * We know this is an AFSDB record for our cell, of the
+		 * right AFSDB type.  Write down the true cell name that
+		 * the resolver gave us above.
+		 */
+		strcpy(realCellName, host);
+	    }
+
 	    code = dn_expand(answer, answer+len, p+2, host, sizeof(host));
 	    if (code < 0)
 		return AFSCONF_NOTFOUND;
@@ -630,6 +726,12 @@ afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
 
     if (server_num == 0)		/* No AFSDB records */
 	return AFSCONF_NOTFOUND;
+
+    /* Convert the real cell name to lowercase */
+    for (p = (unsigned char *) realCellName; *p; p++)
+	*p = tolower(*p);
+
+    strncpy(acellInfo->name, realCellName, sizeof(acellInfo->name));
     acellInfo->numServers = server_num;
 
     if (aservice) {
@@ -645,6 +747,58 @@ afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
 
     return 0;
 }
+#else  /* windows */
+int afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
+  char *aservice;
+  char *acellName;
+  struct afsconf_cell *acellInfo;
+{
+    register afs_int32 i;
+    int tservice;
+    struct afsconf_entry DNSce;
+    char *DNStmpStrp; /* a temp string pointer */
+    struct hostent *thp;
+    afs_int32 cellHosts[AFSMAXCELLHOSTS];
+    int numServers;
+    int rc;
+    int *ttl;
+
+    DNSce.cellInfo.numServers=0;
+    DNSce.next = NULL;
+    rc = getAFSServer(acellName, cellHosts, &numServers, &ttl);
+    /* ignore the ttl here since this code is only called by transitory programs
+       like klog, etc. */
+    if (rc < 0)
+      return -1;
+    if (numServers == 0)
+      return -1;
+
+    for (i = 0; i < numServers; i++)
+    {
+        memcpy(&acellInfo->hostAddr[i].sin_addr.s_addr, &cellHosts[i], sizeof(long));
+        acellInfo->hostAddr[i].sin_family = AF_INET;
+
+        /* sin_port supplied by connection code */
+    }
+
+    acellInfo->numServers = numServers;
+    strcpy(acellInfo->name, acellName);
+    if (aservice) {
+        LOCK_GLOBAL_MUTEX
+        tservice = afsconf_FindService(aservice);
+	UNLOCK_GLOBAL_MUTEX
+        if (tservice < 0) {
+            return AFSCONF_NOTFOUND;  /* service not found */
+     }
+     for(i=0; i< acellInfo->numServers; i++) {
+            acellInfo->hostAddr[i].sin_port = tservice;
+     }
+    }
+    acellInfo->linkedCell = NULL;    /* no linked cell */
+    acellInfo->flags = 0;
+    return 0;
+}
+#endif /* windows */
 #endif /* AFS_AFSDB_ENV */
 
 afsconf_GetCellInfo(adir, acellName, aservice, acellInfo)
@@ -653,6 +807,7 @@ char *aservice;
 char *acellName;
 struct afsconf_cell *acellInfo; {
     register struct afsconf_entry *tce;
+    struct afsconf_aliasentry *tcae;
     struct afsconf_entry *bestce;
     register afs_int32 i;
     int tservice;
@@ -684,6 +839,15 @@ struct afsconf_cell *acellInfo; {
 	UNLOCK_GLOBAL_MUTEX
 	return 0;
     }
+
+    /* Look through the list of aliases */
+    for (tcae = adir->alias_entries; tcae; tcae = tcae->next) {
+	if (strcasecmp(tcae->aliasInfo.aliasName, tcell) == 0) {
+	    tcell = tcae->aliasInfo.realName;
+	    break;
+	}
+    }
+
     for(tce=adir->entries;tce;tce=tce->next) {
 	if (strcasecmp(tce->cellInfo.name, tcell) == 0) {
 	    /* found our cell */
@@ -716,7 +880,7 @@ struct afsconf_cell *acellInfo; {
     else {
 	UNLOCK_GLOBAL_MUTEX
 #ifdef AFS_AFSDB_ENV
-	return afsconf_GetAfsdbInfo(acellName, aservice, acellInfo);
+	return afsconf_GetAfsdbInfo(tcell, aservice, acellInfo);
 #else
 	return AFSCONF_NOTFOUND;
 #endif /* AFS_AFSDB_ENV */
@@ -860,8 +1024,10 @@ struct afsconf_keys *astr;
 
     LOCK_GLOBAL_MUTEX
     code = afsconf_Check(adir);
-    if (code)
+    if (code) {
+        UNLOCK_GLOBAL_MUTEX
 	return AFSCONF_FAILURE;
+    }
     memcpy(astr, adir->keystr, sizeof(struct afsconf_keys));
     UNLOCK_GLOBAL_MUTEX
     return 0;
@@ -882,8 +1048,10 @@ afs_int32 afsconf_GetLatestKey(adir, avno, akey)
     
     LOCK_GLOBAL_MUTEX
     code = afsconf_Check(adir);
-    if (code)
+    if (code) {
+        UNLOCK_GLOBAL_MUTEX
 	return AFSCONF_FAILURE;
+    }
     maxa = adir->keystr->nkeys;
 
     best = -1;	    /* highest kvno we've seen yet */
@@ -917,8 +1085,10 @@ char *akey;
 
     LOCK_GLOBAL_MUTEX
     code = afsconf_Check(adir);
-    if (code)
+    if (code) {
+        UNLOCK_GLOBAL_MUTEX
 	return AFSCONF_FAILURE;
+    }
     maxa = adir->keystr->nkeys;
 
     for(tk = adir->keystr->key,i=0;i<maxa;i++,tk++) {
