@@ -16,7 +16,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/ktc.c,v 1.1.1.6 2001/09/11 14:31:22 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/auth/ktc.c,v 1.1.1.9 2003/07/30 17:11:22 hartmans Exp $");
 
 #if defined(UKERNEL)
 #include "../afs/sysincludes.h"
@@ -48,10 +48,20 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/ktc.c,v 1.
 #include <errno.h>
 #include <sys/ioctl.h>
 #include <netinet/in.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <afs/vice.h>
 #ifdef	AFS_AIX_ENV
 #include <sys/lockf.h>
 #endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include "auth.h"
 #include <afs/venus.h>
 #include <afs/afsutil.h>
@@ -121,7 +131,10 @@ static struct flock fileUlock = { F_UNLCK, 0, 0, 0, 0 };
  */
 int afs_tf_init(), afs_tf_get_pname(), afs_tf_get_pinst(), afs_tf_get_cred(); 
 int afs_tf_save_cred(), afs_tf_close(), afs_tf_create(); 
-int afs_tf_dest_tkt(), ktc_LocalCell();
+int afs_tf_dest_tkt();
+/* except ktc_LocalCell which is still static
+ */
+static int ktc_LocalCell();
 char *ktc_tkt_string();
 #endif  /* AFS_KERBEROS_ENV */
 
@@ -1264,7 +1277,7 @@ afs_tf_save_cred(aserver, atoken, aclient)
     struct ktc_principal principal;
     struct ktc_token token;
     int     status;
-    off_t   start, lseek();
+    off_t   start;
     int     lifetime, kvno;
     int     count;		/* count for write */
 
