@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/bozo/bnode.c,v 1.1.1.6 2001/09/11 14:31:25 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/bozo/bnode.c,v 1.1.1.9 2002/09/26 19:04:55 hartmans Exp $");
 
 #include <stddef.h>
 #include <stdlib.h>
@@ -34,6 +34,11 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/bozo/bnode.c,v
 #include <afs/fileutil.h>
 #include "bnode.h"
 
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN4_ENV)
+/* All known versions of AIX lack WCOREDUMP but this works */
+#define WCOREDUMP(x) ((x) & 0x80)
+#endif
+
 #define BNODE_LWP_STACKSIZE	(16 * 1024)
 
 int bnode_waiting = 0;
@@ -528,6 +533,12 @@ static int bproc() {
 			    RememberProcName(tp);
 			    tb->errorSignal = 0;
 			}
+			if (tp->coreName)
+			    bozo_Log("%s:%s exited with code %d\n",
+				tb->name, tp->coreName, tp->lastExit);
+			else
+			    bozo_Log("%s exited with code %d\n",
+				tb->name, tp->lastExit);
 		    }
 		    else {
 			/* Signal occurred, perhaps spurious due to shutdown request.
@@ -542,6 +553,14 @@ static int bproc() {
 			    tb->lastErrorExit = FT_ApproxTime();
 			    RememberProcName(tp);
 			}
+			if (tp->coreName)
+			    bozo_Log("%s:%s exited on signal %d%s\n",
+				tb->name, tp->coreName, tp->lastSignal,
+				WCOREDUMP(status) ? " (core dumped)" : "");
+			else
+			    bozo_Log("%s exited on signal %d%s\n",
+				tb->name, tp->lastSignal,
+				WCOREDUMP(status) ? " (core dumped)" : "");
 			SaveCore(tb, tp);
 		    }
 		    tb->lastAnyExit = FT_ApproxTime();
