@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/bozo/bos.c,v 1.1.1.8 2001/09/20 06:12:42 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/bozo/bos.c,v 1.1.1.10 2002/09/26 19:04:56 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <stdlib.h>
@@ -1259,7 +1259,10 @@ char *orphans;
     parms[1] = "now";	    /* when to do it */
     code = BOZO_CreateBnode(aconn, "cron", "salvage-tmp", parms[0], parms[1],
 			    parms[2], parms[3], parms[4], notifier);
-    if (code) goto done;
+    if (code) {
+	printf("bos: failed to start 'salvager' (%s)\n", em(code));
+	goto done;
+    }
     /* now wait for bnode to disappear */
     while (1) {
 	IOMGR_Sleep(5);
@@ -1485,7 +1488,6 @@ struct cmd_syndesc *as; {
 	/* now do the salvage operation */
 	printf("Starting salvage.\n");
 	rc = DoSalvage(tconn, (char *) 0, (char *) 0, outName, showlog,parallel,tmpDir,orphans);
-	if (rc) printf("bos: failed to start 'salvager' (%s)\n", em(rc));
 	if (curGoal == BSTAT_NORMAL) {
 	    printf("bos: restarting fs.\n");
 	    code = BOZO_SetTStatus(tconn, "fs", BSTAT_NORMAL);
@@ -1526,7 +1528,6 @@ struct cmd_syndesc *as; {
 	printf("Starting salvage.\n");
 	rc = DoSalvage(tconn, as->parms[1].items->data, (char *) 0,
 		       outName, showlog,parallel,tmpDir,orphans);
-	if (rc) printf("bos: failed to start 'salvager' (%s)\n", em(rc));
 	if (curGoal == BSTAT_NORMAL) {
 	    printf("bos: restarting fs.\n");
 	    code = BOZO_SetTStatus(tconn, "fs", BSTAT_NORMAL);
@@ -1578,10 +1579,8 @@ struct cmd_syndesc *as; {
 	printf("Starting salvage.\n");
 	rc = DoSalvage(tconn, as->parms[1].items->data, tname, outName,
 		       showlog,parallel,tmpDir,orphans);
-	if (rc) {
-	   printf("bos: failed to start 'salvager' (%s)\n", em(rc));
+	if (rc) 
 	   return rc;
-	}
     }
     return 0;
 }
@@ -1829,7 +1828,7 @@ main(argc, argv)
     cmd_AddParm(ts, "-instance", CMD_LIST, CMD_OPTIONAL, "instances");
     add_std_args (ts);
 
-    ts = cmd_CreateSyntax("restart", Restart, 0, "restart all processes");
+    ts = cmd_CreateSyntax("restart", Restart, 0, "restart processes");
     cmd_AddParm(ts, "-server", CMD_SINGLE, 0, "machine name");
     cmd_AddParm(ts, "-instance", CMD_LIST, CMD_OPTIONAL, "instances");
     cmd_AddParm(ts, "-bosserver", CMD_FLAG, CMD_OPTIONAL, "restart bosserver");
