@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/bozo/bosoprocs.c,v 1.1.1.10 2002/05/10 23:57:24 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/bozo/bosoprocs.c,v 1.1.1.11 2002/09/26 19:04:57 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -1260,6 +1260,13 @@ int DirAccessOK ()
     for (i=0; i<bozo_nbosEntryStats; i++) {
 	struct bozo_bosEntryStats *e = &bozo_bosEntryStats[i];
 	if (!StatEachEntry (e)) {
+	    bozo_Log("unhappy with %s which is a %s that should "
+		     "have at least rights %o, at most rights %o %s\n",
+		     e->path, 
+		     e->dir ? "dir" : "file", 
+		     e->reqPerm, 
+		     e->proPerm, 
+		     e->rootOwner ? ", owned by root" : "");
 	    result = 0;
 	    break;
 	}
