@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/budb/dbs_dump.c,v 1.1.1.4 2001/07/14 22:20:58 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/budb/dbs_dump.c,v 1.1.1.5 2001/09/11 14:31:43 hartmans Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -143,7 +143,7 @@ afs_int32 DumpDB (call, firstcall, maxLength, charListPtr, done)
 	LogDebug(5, "Setup dump\n");
 
 	/* no dump in progress - setup and retake lock */
-	bzero(dumpSyncPtr, sizeof(*dumpSyncPtr));
+	memset(dumpSyncPtr, 0, sizeof(*dumpSyncPtr));
 /*	ObtainWriteLock(&dumpSyncPtr->ds_lock); */
 
 	/* mark dump in progress */
@@ -320,7 +320,7 @@ dumpWatcher()
 		if (code) LogError(code, "Aborting dump transaction\n");
 	    }
 
-	    bzero(dumpSyncPtr, sizeof(*dumpSyncPtr));
+	    memset(dumpSyncPtr, 0, sizeof(*dumpSyncPtr));
 	    goto exit;
 	} /*i*/
 
