@@ -20,15 +20,16 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/cksum.c,v 1.1.1.5 2001/07/14 22:21:27 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/des/cksum.c,v 1.1.1.6 2001/09/11 14:32:26 hartmans Exp $");
 
 #include <mit-cpyright.h>
 #include <stdio.h>
-#if defined(HAVE_STRINGS_H)
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
-#if defined(HAVE_STRING_H)
-#include <string.h>
 #endif
 
 #include <des.h>
@@ -74,8 +75,8 @@ des_cbc_cksum(in,out,length,key,iv)
 
 #ifdef MUSTALIGN
     if ((afs_int32) ivec & 3) {
-	bcopy((char *)ivec++,(char *)&t_output[0],sizeof(t_output[0]));
-	bcopy((char *)ivec,(char *)&t_output[1],sizeof(t_output[1]));
+	memcpy((char *)&t_output[0], (char *)ivec++, sizeof(t_output[0]));
+	memcpy((char *)&t_output[1], (char *)ivec, sizeof(t_output[1]));
     }
     else
 #endif
@@ -88,8 +89,8 @@ des_cbc_cksum(in,out,length,key,iv)
 	/* get input */
 #ifdef MUSTALIGN
 	if ((afs_int32) input & 3) {
-	    bcopy((char *)input++,(char *)&t_input[0],sizeof(t_input[0]));
-	    bcopy((char *)input++,(char *)&t_input[1],sizeof(t_input[1]));
+	    memcpy((char *)&t_input[0], (char *)input++, sizeof(t_input[0]));
+	    memcpy((char *)&t_input[1], (char *)input++, sizeof(t_input[1]));
 	}
 	else
 #endif
@@ -126,8 +127,8 @@ des_cbc_cksum(in,out,length,key,iv)
     /* copy temp output and save it for checksum */
 #ifdef MUSTALIGN
     if ((afs_int32) output & 3) {
-	bcopy((char *)&t_output[0],(char *)output++,sizeof(t_output[0]));
-	bcopy((char *)&t_output[1],(char *)output,sizeof(t_output[1]));
+	memcpy((char *)output++, (char *)&t_output[0], sizeof(t_output[0]));
+	memcpy((char *)output, (char *)&t_output[1], sizeof(t_output[1]));
     }
     else
 #endif
