@@ -37,17 +37,18 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/crypt.c,v 1.1.1.4 2001/07/14 22:21:31 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/des/crypt.c,v 1.1.1.7 2003/07/30 17:11:51 hartmans Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <windows.h>
 #endif
 #include <stdlib.h>
-#if defined(HAVE_STRINGS_H)
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
-#if defined(HAVE_STRING_H)
-#include <string.h>
 #endif
 
 /*
@@ -87,7 +88,9 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/crypt.c,v 1
  * define "LONG_IS_32_BITS" only if sizeof(long)==4.
  * This avoids use of bit fields (your compiler may be sloppy with them).
  */
-#if !defined(cray)
+
+/* XXX shouldn't this be !AFS_64BIT_ENV ? */
+#if !defined(cray) && !defined(AFS_ALPHA_LINUX20_ENV) && !defined(AFS_IA64_LINUX20_ENV) && !defined(AFS_AMD64_LINUX20_ENV)
 #define	LONG_IS_32_BITS
 #endif
 
@@ -500,6 +503,7 @@ crypt(key, setting)
 	int num_iter, salt_size;
 	C_block keyblock, rsltblock;
 
+
 	for (i = 0; i < 8; i++) {
 		if ((t = 2*(unsigned char)(*key)) != 0)
 			key++;
