@@ -36,7 +36,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/des.c,v 1.1.1.4 2001/07/14 22:21:31 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/des/des.c,v 1.1.1.5 2001/09/11 14:32:30 hartmans Exp $");
 
 #include <stdio.h>
 #ifdef AFS_PTHREAD_ENV
@@ -130,8 +130,8 @@ des_ecb_encrypt(clear, cipher, schedule, encrypt)
     }
 #endif
     if ((afs_int32) clear & 3) {
-	bcopy((char *)clear++,(char *)&L_save,sizeof(L_save));
-	bcopy((char *)clear,(char *)&R_save,sizeof(R_save));
+	memcpy((char *)&L_save, (char *)clear++, sizeof(L_save));
+	memcpy((char *)&R_save, (char *)clear, sizeof(R_save));
 	L1 = L_save;
 	R1 = R_save;
     }
@@ -442,8 +442,8 @@ des_ecb_encrypt(clear, cipher, schedule, encrypt)
     if ((afs_int32) cipher & 3) {
 	L_save = L2;	/* cant bcopy a reg */
 	R_save = R2;
-	bcopy((char *)&L_save,(char *)cipher++,sizeof(L_save));
-	bcopy((char *)&R_save,(char *)cipher,sizeof(R_save));
+	memcpy((char *)cipher++, (char *)&L_save, sizeof(L_save));
+	memcpy((char *)cipher, (char *)&R_save, sizeof(R_save));
     }
     else
 #endif
