@@ -13,12 +13,14 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/misc.c,v 1.1.1.4 2001/07/14 22:21:35 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/des/misc.c,v 1.1.1.5 2001/09/11 14:32:31 hartmans Exp $");
 
 #include <mit-cpyright.h>
 #include <stdio.h>
 #include "des_internal.h"
 
+int des_debug;
+
 /*
  * The DES algorithm is defined in terms of MSBFIRST, so sometimes,
  * e.g.  VAXes, we need to fix it up.  ANSI order means the DES
@@ -286,70 +288,3 @@ void test_set(stream, src, testbit, dest, setbit)
 #endif
 }
 
-extern void gen PROTOTYPE((FILE * stream));
-int des_debug;
-char const *whoami;
-
-
-#ifndef DONT_INCL_MAIN
-
-#include "AFS_component_version_number.c"
-
-int main(argc, argv)
-    int argc;
-    char *argv[];
-{
-    char *filename;
-    char *arg;
-    FILE * stream;
-
-    whoami = argv[0];
-    filename = (char *)NULL;
-
-    while (argc--, *++argv) {
-        arg = *argv;
-        if (*arg == '-') {
-            if (!strcmp(arg, "-d") && !strcmp(arg, "-debug"))
-                des_debug++;
-            else {
-                fprintf(stderr, "%s: unknown control argument %s\n",
-                        whoami, arg);
-                goto usage;
-            }
-        }
-        else if (filename) {
-            fprintf(stderr,
-                    "%s: multiple file names provided: %s, %s\n",
-                    whoami, filename, arg);
-            goto usage;
-        }
-        else
-            filename = arg;
-    }
-
-    if (!filename) {
-        fprintf(stderr, "%s: no file name provided\n", whoami);
-        goto usage;
-    }
-
-    stream = fopen(filename, "w");
-    if (!stream) {
-        perror(filename);
-    usage:
-        fprintf(stderr, "usage: %s [-debug] filename\n", whoami);
-        exit(1);
-    }
-
-    fputs(
-      "/* This file is automatically generated.  Do not edit it. */\n",
-          stream);
-
-    /* This routine will generate the contents of the file. */
-    gen(stream);
-    if (fclose(stream) == EOF) {
-        perror(filename);
-        exit(1);
-    }
-    exit(0);
-}
-#endif	/* DONT_INCL_MAIN */
