@@ -14,7 +14,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/inetd/ta-rauth.c,v 1.1.1.4 2001/07/14 22:22:07 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/inetd/ta-rauth.c,v 1.1.1.5 2001/09/11 14:32:51 hartmans Exp $");
 
 #include <sys/types.h>
 #include <sys/param.h>
@@ -177,7 +177,7 @@ outtoken(s,token,svc,localName)
 
     /* (4) sessionKey */
     bp = buf + strlen(buf);
-    bcopy(&token->sessionKey,bp,8);
+    memcpy(bp, &token->sessionKey, 8);
     bp += 8;
 
     /* (5) - (6) */
@@ -185,7 +185,7 @@ outtoken(s,token,svc,localName)
 
     /* (7) ticket */
     bp += strlen(bp);
-    bcopy(token->ticket, bp, token->ticketLen);
+    memcpy(bp, token->ticket, token->ticketLen);
     bp += token->ticketLen;
 
     if((count = write(s, buf, (int)(bp - buf))) == -1) {
