@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/klog.c,v 1.1.1.5 2001/09/11 14:32:58 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/kauth/klog.c,v 1.1.1.6 2001/10/14 18:05:08 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -18,6 +18,13 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/klog.c,v
 #ifdef	AFS_AIX32_ENV
 #include <signal.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 
 #include <lock.h>
 #include <ubik.h>
