@@ -15,18 +15,27 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/krb_udp.c,v 1.1.1.10 2001/09/20 06:15:00 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/kauth/krb_udp.c,v 1.1.1.14 2003/04/13 19:06:46 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
+#include <errno.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
+#include <afs/errmap_nt.h>
 #define snprintf _snprintf
 #else
 #include <sys/socket.h>
 #include <netdb.h>
 #include <netinet/in.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <afs/afsutil.h>
 #include <time.h>
 #include <afs/com_err.h>
@@ -453,6 +462,11 @@ afs_int32 UDP_GetTicket (ksoc, pkt, kvno, authDomain, ticket, ticketLen, auth, a
 	cell[MAXKTCREALMLEN-1] = 0;
     };
 
+    if (!krb4_cross && strcmp(lrealm, cell) != 0) {
+	code = KERB_ERR_PRINCIPAL_UNKNOWN;
+	goto abort;
+    }
+
     if (krb_udp_debug) {
 	printf ("UGetTicket: got ticket from '%s'.'%s'@'%s'\n",
 		name, inst, cell);
@@ -771,6 +785,8 @@ static SocketListener ()
 	    code = recvfrom(sock_kerb, packet.data, sizeof(packet.data), 0,
 			    (struct sockaddr *) &packet.from, &fromLen);
 	    if (code < 0) {
+		if (errno == EAGAIN || errno == ECONNREFUSED) 
+		    goto try_kerb5;
 		perror ("calling recvfrom");
 		break;
 	    }
@@ -785,10 +801,13 @@ static SocketListener ()
 	    packet.time = 0;
 	    process_udp_request (sock_kerb, &packet);
 	} 
+try_kerb5:
 	if ((sock_kerb5 >= 0) && FD_ISSET(sock_kerb5, &rfds)) {
 	    code = recvfrom(sock_kerb5, packet.data, sizeof(packet.data), 0,
 			    (struct sockaddr *) &packet.from, &fromLen);
 	    if (code < 0) {
+		if (errno == EAGAIN || errno == ECONNREFUSED) 
+		    continue;
 		perror ("calling recvfrom");
 		break;
 	    }
@@ -804,6 +823,15 @@ static SocketListener ()
 	    process_udp_request (sock_kerb5, &packet);
 	} 
     }
+    if (sock_kerb >= 0) {
+	close(sock_kerb);
+	sock_kerb = -1;
+    }
+    if (sock_kerb5 >= 0) {
+	close(sock_kerb5);
+	sock_kerb5 = -1;
+    }
+    printf("UDP SocketListener exiting due to error\n");
 }
 
 #if MAIN
@@ -834,6 +862,9 @@ afs_int32 init_krb_udp ()
     krb4name = "kerberos4";
     sp = getservbyname(krb4name, "udp");
     taddr.sin_family = AF_INET;  /* added for NCR port */
+#ifdef STRUCT_SOCKADDR_HAS_SA_LEN
+    taddr.sin_len = sizeof(struct sockaddr_in);
+#endif
     if ( !sp )	
     {
 	/* if kerberos-4 is not available, try "kerberos-iv" */
