@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/libadmin/bos/afs_bosAdmin.c,v 1.1.1.6 2001/07/14 22:22:25 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/libadmin/bos/afs_bosAdmin.c,v 1.1.1.8 2002/05/10 23:59:18 hartmans Exp $");
 
 #include <stdio.h>
 #include <afs/stds.h>
@@ -64,8 +64,8 @@ extern int BOZO_RestartAll();
 extern int BOZO_SetCellName();
 extern int BOZO_SetNoAuthFlag();
 extern int BOZO_SetRestartTime();
-extern int BOZO_SetStatus(struct rx_connection *, const char *, long);
-extern int BOZO_SetTStatus(struct rx_connection *, const char *, long);
+extern int BOZO_SetStatus(struct rx_connection *, char *, afs_int32);
+extern int BOZO_SetTStatus(struct rx_connection *, char *, afs_int32);
 extern int BOZO_ShutdownAll();
 extern int BOZO_StartupAll();
 extern int BOZO_UnInstall();
@@ -3112,7 +3112,7 @@ int ADMINAPI bos_ExecutableRestartTimeSet(
     restartTime.sec = time.sec;
     restartTime.day = time.day;
 
-    tst = BOZO_SetRestartTime(b_handle->server, restartType, restartTime);
+    tst = BOZO_SetRestartTime(b_handle->server, restartType, &restartTime);
 
     if (tst == 0) {
 	rc = 1;
