@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/libadmin/pts/afs_ptsAdmin.c,v 1.1.1.5 2002/05/10 23:59:34 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/libadmin/pts/afs_ptsAdmin.c,v 1.1.1.6 2003/07/30 17:12:12 hartmans Exp $");
 
 #include <stdio.h>
 #include <afs/stds.h>
@@ -2682,7 +2682,7 @@ static int GetOwnedGroupRPC(
      * We can retrieve the next group from data we already received
      */
 
-    strcpy(&list->group[slot], &list->owned_names.namelist_val[list->index]);
+    strcpy(list->group[slot], list->owned_names.namelist_val[list->index]);
     list->index++;
 
     /*
@@ -2725,7 +2725,7 @@ static int GetOwnedGroupFromCache(
     afs_status_t tst = 0;
     owned_group_list_p list = (owned_group_list_p) rpc_specific;
 
-    strcpy((char *) dest, &list->group[slot]);
+    strcpy((char *) dest, list->group[slot]);
     rc = 1;
 
     if (st != NULL) {
@@ -3029,7 +3029,7 @@ static int GetPTSRPC(
      * We can retrieve the next entry from data we already received
      */
 
-    strcpy(&list->entries[slot], list->currName->name);
+    strcpy(list->entries[slot], list->currName->name);
     list->index++;
     list->currName++;
 
@@ -3072,7 +3072,7 @@ static int GetPTSFromCache(
     afs_status_t tst = 0;
     pts_list_p list = (pts_list_p) rpc_specific;
 
-    strcpy((char *) dest, &list->entries[slot]);
+    strcpy((char *) dest, list->entries[slot]);
     rc = 1;
 
     if (st != NULL) {
