@@ -7,8 +7,6 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
 /*
         unlog -- Tell the Andrew Cache Manager to either clean up your connection completely
                     or eliminate the caller's PAG.
@@ -28,7 +26,11 @@
 #define	VIRTUE	    1
 #define	VICE	    1
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/log/unlog.c,v 1.1.1.4 2001/07/14 22:22:50 hartmans Exp $");
+
 #include <stdio.h>
 #include <potpourri.h>
 #ifdef	AFS_AIX32_ENV
