@@ -39,7 +39,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/login/login.c,v 1.1.1.4 2001/07/14 22:22:52 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/login/login.c,v 1.1.1.6 2002/12/11 02:43:50 hartmans Exp $");
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -747,7 +747,7 @@ doafs:
 		    (void)signal(SIGTSTP, SIG_IGN);
 		    
 		    tbuf[0] = '-';
-		    (void)strcpy(tbuf + 1, (p = rindex(shell, '/')) ? p + 1 : shell);
+		    (void)strcpy(tbuf + 1, (p = strrchr(shell, '/')) ? p + 1 : shell);
 		    sia_ses_release(&entity);
 		    execlp(shell, tbuf, 0);
 		    (void)printf("login: no shell: %s.\n", strerror(errno));
@@ -1439,7 +1439,7 @@ int prompt;
 				exit(0);
 			}
 			if (p < nbuf + UT_NAMESIZE)
-				*p++ = ch;
+				*p++ = (char) ch;
 		}
 		if (p > nbuf) {
 			if (nbuf[0] == '-')
@@ -2040,7 +2040,7 @@ static char *getlinep(const char *string, int size, FILE *stream) {
     if(!fgets(string, size, stream) || ferror(stream) || errno == EINTR)
 	return NULL;
     else
-	if(cp=index(string, '\n'))
+	if(cp=strchr(string, '\n'))
 	    *cp = '\0';
 	else
 	    while((c=getc(stdin)) != '\n' && c != EOF && errno != EINTR)
