@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/login/util_logout.c,v 1.1.1.3 2001/07/14 22:22:52 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/login/util_logout.c,v 1.1.1.4 2001/09/11 14:33:33 hartmans Exp $");
 
 #include <sys/types.h>
 #include <sys/file.h>
@@ -54,9 +54,9 @@ logout(line)
 		if (!ut.ut_name[0] ||
 		    strncmp(ut.ut_line, line, sizeof(ut.ut_line)))
 			continue;
-		bzero(ut.ut_name, sizeof(ut.ut_name));
+		memset(ut.ut_name, 0, sizeof(ut.ut_name));
 #if	!defined(AIX) && !defined(AFS_SUN5_ENV)
-		bzero(ut.ut_host, sizeof(ut.ut_host));
+		memset(ut.ut_host, 0, sizeof(ut.ut_host));
 #endif /* AIX */
 		(void)time(&ut.ut_time);
 		(void)fseek(fp, (long)-sizeof(struct utmp), L_INCR);
