@@ -17,7 +17,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/lwp/lwp.c,v 1.1.1.8 2001/07/14 22:22:55 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/lwp/lwp.c,v 1.1.1.9 2001/09/11 14:33:36 hartmans Exp $");
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -1252,7 +1252,7 @@ static PROCESS lwp_alloc_process(name, ep, arg)
 {
     PROCESS lp;
     assert(lp = (PROCESS) malloc(sizeof (*lp)));
-    bzero((char *) lp, sizeof(*lp));
+    memset((char *) lp, 0, sizeof(*lp));
     if (!name) {
 	char temp[100];
 	static procnum;
