@@ -16,7 +16,11 @@
  * required lib is kernel32.lib, header is winbase.h
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/lwp/lwp_nt.c,v 1.1.1.6 2001/07/14 22:22:55 hartmans Exp $");
+
 #ifdef AFS_NT40_ENV
 #include <stdio.h>
 #include <stdlib.h>
@@ -99,8 +103,29 @@ struct QUEUE {
 	    }\
 	}
 
+#ifdef AFS_WIN95_ENV
+
+LPVOID ConvertThreadToFiber(PROCESS x)
+{
+	return NULL;
+}
+LPVOID CreateFiber(DWORD x ,LPVOID y,PROCESS z)
+{
+	return NULL;
+}
+
+VOID SwitchToFiber(LPVOID p)
+{
+}
+
+VOID DeleteFiber(LPVOID p)
+{
+}
+#endif
+
 
 int lwp_MinStackSize = 0;
+
 /* LWP_InitializeProcessSupport - setup base support for fibers.
  *
  * Arguments:
@@ -112,6 +137,7 @@ int lwp_MinStackSize = 0;
  *	LWP_SUCCESS (else aborts)
  *	
  */
+
 int LWP_InitializeProcessSupport(int priority, PROCESS *pid)
 {
     PROCESS pcb;
@@ -602,6 +628,7 @@ static void Delete_PCB(PROCESS pid)
     LWPANCHOR.processcnt--;
 }
 
+
 static void Free_PCB(PROCESS pid)
 {
     Debug(4, ("Entered Free_PCB"))
