@@ -16,7 +16,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/lwp/preempt.c,v 1.1.1.10 2001/09/20 06:15:31 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/lwp/preempt.c,v 1.1.1.12 2002/09/26 19:06:55 hartmans Exp $");
 
 
 #if defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_DJGPP_ENV)
@@ -24,7 +24,9 @@ int PRE_Block = 0;
 #else
 #include <sys/time.h>
 #include <signal.h>
+#ifdef HAVE_UCONTEXT_H
 #include <ucontext.h>
+#endif
 #include "lwp.h"
 #include "preempt.h"
 
@@ -34,15 +36,25 @@ int PRE_Block = 0;		/* used in lwp.c and process.s */
 char PRE_Block = 0;		/* used in lwp.c and process.s */
 #endif
 
+#if HAVE_SIGACTION && defined(SA_SIGINFO)
 static void AlarmHandler(sig, st, scp)
     int sig;
     siginfo_t *st;
     ucontext_t *scp;
+#else
+static void AlarmHandler(sig, code, scp)
+    int sig, code;
+    struct sigcontext *scp;
+#endif
     {
     if (PRE_Block == 0 && lwp_cpptr->level == 0)
 	{
 	PRE_BeginCritical();
+#if HAVE_SIGACTION && defined(SA_SIGINFO)
 	sigprocmask(SIG_SETMASK, &scp->uc_sigmask, NULL);
+#else
+	sigsetmask(scp->sc_mask);
+#endif
 	LWP_DispatchProcess();
 	PRE_EndCritical();
 	}
@@ -53,7 +65,11 @@ int PRE_InitPreempt(slice)
     struct timeval *slice;
     {
     struct itimerval itv;
+#if HAVE_SIGACTION && defined(SA_SIGINFO)
     struct sigaction action;
+#else
+    struct sigvec vec;
+#endif
 
     if (lwp_cpptr == 0) return (LWP_EINIT);
     
@@ -67,6 +83,7 @@ int PRE_InitPreempt(slice)
 	itv.it_interval = itv.it_value = *slice;
 	}
 
+#if HAVE_SIGACTION && defined(SA_SIGINFO)
     memset((char *)&action, 0, sizeof(action));
     action.sa_sigaction = AlarmHandler;
     action.sa_flags = SA_SIGINFO;
@@ -74,6 +91,15 @@ int PRE_InitPreempt(slice)
     if ((sigaction(SIGALRM, &action, (struct sigaction *)0) == -1) ||
 	(setitimer(ITIMER_REAL, &itv, (struct itimerval *) 0) == -1))
 	return(LWP_ESYSTEM);
+#else
+    memset((char *)&vec, 0, sizeof(vec));
+    vec.sv_handler = AlarmHandler;
+    vec.sv_mask = vec.sv_onstack = 0;
+
+    if ((sigvec(SIGALRM, &vec, (struct sigvec *)0) == -1) ||
+	(setitimer(ITIMER_REAL, &itv, (struct itimerval *) 0) == -1))
+	return(LWP_ESYSTEM);
+#endif
 
     return(LWP_SUCCESS);
     }
@@ -81,18 +107,32 @@ int PRE_InitPreempt(slice)
 int PRE_EndPreempt()
     {
     struct itimerval itv;
+#if HAVE_SIGACTION && defined(SA_SIGINFO)
     struct sigaction action;
+#else
+    struct sigvec vec;
+#endif
 
     if (lwp_cpptr == 0) return (LWP_EINIT);
     
     itv.it_value.tv_sec = itv.it_value.tv_usec = 0;
 
+#if HAVE_SIGACTION && defined(SA_SIGINFO)
     memset((char *)&action, 0, sizeof(action));
     action.sa_handler = SIG_DFL;
 
     if ((setitimer(ITIMER_REAL, &itv, (struct itimerval *) 0) == -1) ||
 	(sigaction(SIGALRM, &action, (struct sigaction *)0) == -1))
 	return(LWP_ESYSTEM);
+#else
+    memset((char *)&vec, 0, sizeof(vec));
+    vec.sv_handler = SIG_DFL;
+    vec.sv_mask = vec.sv_onstack = 0;
+
+    if ((setitimer(ITIMER_REAL, &itv, (struct itimerval *) 0) == -1) ||
+	(sigvec(SIGALRM, &vec, (struct sigvec *)0) == -1))
+	return(LWP_ESYSTEM);
+#endif
 
     return(LWP_SUCCESS);
     }
