@@ -12,7 +12,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/lwp/process.c,v 1.1.1.9 2001/07/14 22:22:56 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/lwp/process.c,v 1.1.1.12 2003/07/30 17:12:22 hartmans Exp $");
 
 #include <stdio.h>
 #include <assert.h>
@@ -27,6 +27,71 @@ extern int PRE_Block;              /* used in lwp.c and process.s */
 extern char PRE_Block;             /* used in lwp.c and process.s */
 #endif
 
+#if defined(USE_UCONTEXT) && defined(HAVE_UCONTEXT_H)
+
+afs_int32
+savecontext(ep, savearea, newsp)
+char	(*ep)();
+struct lwp_context *savearea;
+char*	newsp;
+{
+#if defined(AFS_IA64_LINUX20_ENV)
+	register unsigned long sp __asm__("r12");
+#elif defined(AFS_HPUX1122_ENV)
+/* don't need anything special, will use
+ * ucontext.uc_stack.ss_sp as it matches r12.
+ * This should also work for Linux,
+ * but dont have system to test DEE
+ */
+#elif defined(AFS_AMD64_LINUX24_ENV)
+        register unsigned long sp __asm__("sp");
+#else
+#error	"You need to update stack pointer register for this platform"
+#endif
+
+	PRE_Block = 1;
+
+	savearea->state = 0;
+	getcontext(&savearea->ucontext);
+#if defined(AFS_HPUX1122_ENV)
+	savearea->topstack = savearea->ucontext.uc_stack.ss_sp;
+#else
+	savearea->topstack = sp;
+#endif
+	switch (savearea->state)
+	{
+		case 0:
+			if (newsp)
+			{
+				ucontext_t thread;
+
+				getcontext(&thread);
+				thread.uc_stack.ss_sp = newsp - AFS_LWP_MINSTACKSIZE + sizeof(void *) + sizeof(void *);
+				thread.uc_stack.ss_size = AFS_LWP_MINSTACKSIZE - sizeof(void *);
+				makecontext(&thread, ep, 0);
+				setcontext(&thread);
+			}
+			else
+				(*ep)();
+			break;
+		case 2:
+			break;
+	}
+	return 0;
+}
+
+void
+returnto(savearea)
+struct lwp_context *savearea;
+{
+	PRE_Block = 0;
+
+	savearea->state = 2;
+	setcontext(&savearea->ucontext);
+}
+
+#else
+
 /*
  * Magic stack pointer
  */
@@ -169,3 +234,4 @@ struct lwp_context *savearea;
 	return 0;
 }
 
+#endif
