@@ -32,7 +32,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ntp/ntp.c,v 1.1.1.4 2001/07/14 22:23:05 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/ntp/ntp.c,v 1.1.1.5 2001/09/11 14:33:52 hartmans Exp $");
 
 #include <stdio.h>
 #ifdef	AFS_AIX32_ENV
@@ -160,10 +160,10 @@ main(argc, argv)
 					argv[host]);
 				continue;
 			}
-			bcopy(hp->h_addr, (char *) &dst.sin_addr,hp->h_length);
+			memcpy((char *) &dst.sin_addr, hp->h_addr, hp->h_length);
 		}
 
-		bzero((char *)pkt, sizeof(ntp_data));
+		memset((char *)pkt, 0, sizeof(ntp_data));
 
 		pkt->status = NTPVERSION_1 | NO_WARNING | MODE_CLIENT;
 		pkt->stratum = UNSPECIFIED;
