@@ -16,8 +16,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 #include <sys/wait.h>
+#include <limits.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/pam/afs_util.c,v 1.1.1.5 2001/09/11 14:34:02 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/pam/afs_util.c,v 1.1.1.7 2002/01/22 19:54:10 hartmans Exp $");
 
 #include "afs_util.h"
 
@@ -61,11 +62,12 @@ sigvec(int sig, const struct sigvec* vec, struct sigvec* ovec)
 {
 	assert(0);
 }
-#endif  /* AFS_HPUX110_ENV */
+
 sigsetmask(int mask)
 {
 	assert(0);
 }
+#endif  /* AFS_HPUX110_ENV */
 
 /* converts string to integer */
 
@@ -165,7 +167,7 @@ out:
 /* get the current AFS pag for the calling process */
 static afs_int32 curpag()
 {
-   gid_t groups[30];
+   gid_t groups[NGROUPS_MAX];
    afs_uint32 g0, g1;
    afs_uint32 h, l, ret;
       
