@@ -49,7 +49,7 @@ Generic install command.  Options are:
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/pinstall/install.c,v 1.1.1.7 2001/09/20 06:15:51 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/pinstall/install.c,v 1.1.1.11 2003/07/30 17:12:39 hartmans Exp $");
 
 #include <stdio.h>
 #include <pwd.h>
@@ -81,14 +81,22 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/pinstall/instal
 #include <unistd.h>
 #include <string.h>
 #include <sys/wait.h>
+#include <stdlib.h>
 
 struct stat istat, ostat;
 
-extern int errno;
+/* How many systems don't have strerror now? */
+#ifndef HAVE_STRERROR
+#if !defined(AFS_DARWIN60_ENV)
 extern int sys_nerr;
+#endif
 #if !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
 extern char *sys_errlist[];
 #endif
+#else
+#define ErrorString strerror
+#endif
+
 #if	defined(AFS_AIX_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 extern struct passwd *getpwnam();
 int stripcalled = 0;
@@ -121,6 +129,7 @@ static char *strrpbrk (s, set)
     return 0;
 }
 
+#ifndef HAVE_STRERROR
 char *ErrorString(aerrno)
     int aerrno; {
     static char tbuffer[100];
@@ -131,6 +140,7 @@ char *ErrorString(aerrno)
     }
     return tbuffer;
 }
+#endif
 
 int
 stripName(aname)
@@ -160,7 +170,8 @@ atoo(astr)
 static int
 quickStrip (iname, oname, ignored, copy_only)
 char *iname, *oname; {
-	int pid, status;
+	int pid;
+	pid_t status;
 	static char *strip[] = {
 		"strip", 0, 0,
 	};
@@ -184,7 +195,7 @@ char *iname, *oname; {
 		exit(1);
 
 	    default:			/* parent	*/
-		if (waitpid(pid, &status, 0) != pid) {
+		if (waitpid(pid, &status, 0) != pid && errno != ECHILD) {
 			perror("waitpid");
 			return -1;
 		}
@@ -230,7 +241,7 @@ char *iname, *oname; {
 		exit(1);
 
 	    default:			/* parent	*/
-		if (waitpid(pid, &status, 0) != pid) {
+		if (waitpid(pid, &status, 0) != pid && errno != ECHILD) {
 			perror("waitpid");
 			return -1;
 		}
@@ -475,10 +486,8 @@ main (argc, argv)
 #endif /* AFS_HPUX_ENV */
     char pnametmp[1024];
     int pnamelen;
-#if defined (AFS_AIX_ENV) || defined(AFS_XBSD_ENV)
     afs_int32 newcode;
     static char diskBuffer[BUFSIZE];	/* must be static to avoid compiler bugs for large stuff */
-#endif
     char myHostName[100];
     struct timeval tvp[2];
     int isDir;
