@@ -1,4 +1,4 @@
-/* $Id: pt_util.c,v 1.1.1.5 2001/09/20 06:15:55 hartmans Exp $ */
+/* $Id: pt_util.c,v 1.1.1.7 2003/04/13 19:07:19 hartmans Exp $ */
 
 /*
  *
@@ -16,13 +16,15 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
+#include <errno.h>
 #include <sys/file.h>
 
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ptserver/pt_util.c,v 1.1.1.5 2001/09/20 06:15:55 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/ptserver/pt_util.c,v 1.1.1.7 2003/04/13 19:07:19 hartmans Exp $");
 
+#include <errno.h>
 #include <lock.h>
 #include <netinet/in.h>
 #define UBIK_INTERNALS
@@ -39,7 +41,6 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ptserver/pt_uti
 
 extern char *optarg;
 extern int optind;
-extern int errno;
 
 int display_entry();
 void add_group();
