@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rsh/rsh.c,v 1.1.1.3 2001/07/14 22:23:26 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rsh/rsh.c,v 1.1.1.4 2001/09/11 14:34:13 hartmans Exp $");
 
 #include <unistd.h>		/* select() prototype */
 #include <sys/types.h>		/* fd_set on older platforms */
@@ -139,7 +139,7 @@ main(argc, argv0)
      */
     check_and_run_afs_vers(argv);
 #endif
-	bzero(&ign_act, sizeof(ign_act));
+	memset(&ign_act, 0, sizeof(ign_act));
 	ign_act.sa_handler=SIG_IGN;
 #endif
 	host = strrchr(argv[0], '/');
@@ -331,7 +331,7 @@ another:
 	}
 	(void) setuid(getuid());
 
-	bzero((char *)someSignals, sizeof(someSignals));
+	memset((char *)someSignals, 0, sizeof(someSignals));
 #ifdef	AFS_HPUX_ENV
 	someSignals[0] = mask(SIGINT)|mask(SIGQUIT)|mask(SIGTERM)|mask(SIGHUP);
 #else
