@@ -9,6 +9,15 @@
 
 /* RX:  Globals for internal use, basically */
 
+#include <afsconfig.h>
+#ifdef KERNEL
+#include "../afs/param.h"
+#else
+#include <afs/param.h>
+#endif
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rx/rx_globals.c,v 1.1.1.4 2001/07/14 22:23:31 hartmans Exp $");
+
 /* Enable data initialization when the header file is included */
 #define INIT(stuff) = stuff
 #if defined(AFS_NT40_ENV) && defined(AFS_PTHREAD_ENV)
@@ -18,14 +27,11 @@
 #endif
 
 #ifdef KERNEL
-#include	"../afs/param.h"
 #ifndef UKERNEL
 #include "../h/types.h"
 #else /* !UKERNEL */
 #include	"../afs/sysincludes.h"
-#endif /* !UKERNEL */
-#else /* KERNEL */
-#include	<afs/param.h>
+#endif /* UKERNEL */
 #endif /* KERNEL */
 
 #include "rx_globals.h"
