@@ -14,6 +14,11 @@
 #ifndef _RX_KCOMMON_H_
 #define _RX_KCOMMON_H_
 
+#ifdef AFS_LINUX22_ENV
+#define _LINUX_CODA_FS_I 1
+#define _CODA_HEADER_ 1
+struct coda_inode_info {};
+#endif
 #ifdef AFS_DARWIN_ENV
 #ifndef _MACH_ETAP_H_
 #define _MACH_ETAP_H_
@@ -30,6 +35,7 @@ typedef unsigned short                  etap_event_t;
 #include "../h/vfs.h"		/* stops SUN56 socketvar.h warnings */
 #include "../h/stropts.h"	/* stops SUN56 socketvar.h warnings */
 #include "../h/stream.h"	/* stops SUN56 socketvar.h errors */
+#include "../h/disp.h"
 #endif
 #include "../h/socket.h"
 #ifndef AFS_LINUX22_ENV
@@ -37,9 +43,13 @@ typedef unsigned short                  etap_event_t;
 #include "../h/protosw.h"
 #if !defined(AFS_SUN5_ENV) && !defined(AFS_XBSD_ENV)
 #include "../h/domain.h"
+#if !defined(AFS_HPUX110_ENV)
 #include "../h/dir.h"
+#endif
 #include "../h/buf.h"
+#if !defined(AFS_HPUX110_ENV)
 #include "../h/mbuf.h"
+#endif
 #else
 #if defined(AFS_XBSD_ENV)
 #include "../h/dirent.h"
@@ -53,35 +63,43 @@ typedef unsigned short                  etap_event_t;
 #ifdef AFS_SGI62_ENV
 #include "../h/hashing.h"
 #endif
+#ifdef AFS_FBSD_ENV
+#include "../h/sysctl.h"
+#endif
 #include "../netinet/in.h"
+#ifdef AFS_LINUX22_ENV
+#include "../linux/route.h"
+#else
 #include "../net/route.h"
+#endif
 #include "../netinet/in_systm.h"
 #include "../netinet/ip.h"
-#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV)
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN60_ENV)
 #include "../netinet/in_pcb.h"
 #endif /* ! AFS_HPUX110_ENV && ! AFS_LINUX22_ENV */
 #ifndef AFS_LINUX22_ENV
+#if !defined(AFS_DARWIN60_ENV)
 #include "../netinet/ip_var.h"
+#endif
 #include "../netinet/ip_icmp.h"
 #endif /* AFS_LINUX22_ENV */
 #include "../netinet/udp.h"
-#if !defined(AFS_SGI62_ENV) && !defined(AFS_LINUX22_ENV)
+#if !defined(AFS_SGI62_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN60_ENV)
 #include "../netinet/udp_var.h"
 #endif
 #if defined(AFS_HPUX102_ENV) || (defined(AFS_SGI62_ENV) && !defined(AFS_SGI64_ENV))
 #include "../h/user.h"
 #endif
 #ifdef AFS_LINUX22_ENV
-#define _LINUX_CODA_FS_I
-struct coda_inode_info {};
 #include "../h/sched.h"
 #include "../h/netdevice.h"
+#include "../linux/if.h"
 #else
 #include "../h/proc.h"
 #include "../h/file.h"
-#endif
 #include "../net/if.h"
-#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV)
+#endif
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN60_ENV)
 #include "../netinet/in_var.h"
 #endif /* ! AFS_HPUX110_ENV && ! AFS_LINUX22_ENV */
 #ifndef AFS_LINUX22_ENV
@@ -90,9 +108,7 @@ struct coda_inode_info {};
 #include "../afs/afs_osi.h"
 #include "../rx/rx_kmutex.h"
 #include "../afs/lock.h"
-#ifndef AFS_LINUX22_ENV
-#include "../rpc/xdr.h"
-#endif
+#include "../rx/xdr.h"
 #include "../rx/rx.h"
 #include "../rx/rx_globals.h"
 #include "../afs/longc_procs.h"
