@@ -14,7 +14,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_packet.c,v 1.1.1.6 2001/09/11 14:34:21 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rx/rx_packet.c,v 1.1.1.11 2003/07/30 17:12:47 hartmans Exp $");
 
 #ifdef KERNEL
 #if defined(UKERNEL)
@@ -33,6 +33,12 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_packet.c,
 #include "../afs/sysincludes.h"
 #endif
 #include "../h/socket.h"
+#if !defined(AFS_SUN5_ENV) &&  !defined(AFS_LINUX20_ENV) && !defined(AFS_HPUX110_ENV)
+#if	!defined(AFS_OSF_ENV) && !defined(AFS_AIX41_ENV)
+#include "../sys/mount.h"   /* it gets pulled in by something later anyway */
+#endif
+#include "../h/mbuf.h"
+#endif
 #include "../netinet/in.h"
 #include "../afs/afs_osi.h"
 #include "../rx/rx_kmutex.h"
@@ -42,12 +48,6 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_packet.c,
 #include <sys/sysmacros.h>
 #endif
 #include "../rx/rx_packet.h"
-#if !defined(AFS_SUN5_ENV) &&  !defined(AFS_LINUX20_ENV)
-#if	!defined(AFS_OSF_ENV) && !defined(AFS_AIX41_ENV)
-#include "../sys/mount.h"   /* it gets pulled in by something later anyway */
-#endif
-#include "../h/mbuf.h"
-#endif
 #endif /* defined(UKERNEL) */
 #include "../rx/rx_globals.h"
 #else /* KERNEL */
@@ -272,7 +272,7 @@ static struct rx_packet * allocCBuf(int class)
   queue_Remove(c);
   if (!(c->flags & RX_PKTFLAG_FREE))
     osi_Panic("rxi_AllocPacket: packet not free\n");
-  c->flags &= ~RX_PKTFLAG_FREE;
+  c->flags = 0;		/* clear RX_PKTFLAG_FREE, initialize the rest */
   c->header.flags = 0;
   
 #ifdef KERNEL
@@ -631,7 +631,7 @@ struct rx_packet *rxi_AllocPacketNoLock(class)
   dpf(("Alloc %x, class %d\n", p, class));
   
   queue_Remove(p);
-  p->flags &= ~RX_PKTFLAG_FREE;
+  p->flags = 0;		/* clear RX_PKTFLAG_FREE, initialize the rest */
   p->header.flags = 0;
   
   /* have to do this here because rx_FlushWrite fiddles with the iovs in
@@ -788,8 +788,8 @@ int rxi_ReadPacket(socket, p, host, port)
     * our problems caused by the lack of a length field in the rx header.
     * Use the extra buffer that follows the localdata in each packet
     * structure. */
-    savelen = p->wirevec[p->niovecs].iov_len;
-    p->wirevec[p->niovecs].iov_len += RX_EXTRABUFFERSIZE;
+    savelen = p->wirevec[p->niovecs-1].iov_len;
+    p->wirevec[p->niovecs-1].iov_len += RX_EXTRABUFFERSIZE;
 
     memset((char *)&msg, 0, sizeof(msg));
     msg.msg_name = (char *) &from;
@@ -799,7 +799,7 @@ int rxi_ReadPacket(socket, p, host, port)
     nbytes = rxi_Recvmsg(socket, &msg, 0);
 
    /* restore the vec to its correct state */
-    p->wirevec[p->niovecs].iov_len = savelen;
+    p->wirevec[p->niovecs-1].iov_len = savelen;
 
     p->length = (nbytes - RX_HEADER_SIZE);
     if ((nbytes > tlen) || (p->length  & 0x8000)) {  /* Bogus packet */
@@ -959,7 +959,7 @@ int osi_NetSend(socket, addr, dvec, nvecs, length, istack)
  * message receipt is done in rxk_input or rx_put.
  */
 
-#ifdef AFS_SUN5_ENV
+#if defined(AFS_SUN5_ENV) || defined(AFS_HPUX110_ENV)
 /*
  * Copy an mblock to the contiguous area pointed to by cp.
  * MTUXXX Supposed to skip <off> bytes and copy <len> bytes,
@@ -1081,7 +1081,7 @@ return len;
 
 #if !defined(AFS_LINUX20_ENV)
 int rx_mb_to_packet(amb, free, hdr_len, data_len, phandle)
-#ifdef	AFS_SUN5_ENV
+#if defined(AFS_SUN5_ENV) || defined(AFS_HPUX110_ENV)
 mblk_t *amb;
 #else
 struct mbuf *amb;
@@ -1437,7 +1437,9 @@ static void rxi_SendDebugPacket(struct rx_packet *apacket, osi_socket asocket,
     taddr.sin_family = AF_INET;
     taddr.sin_port = aport;
     taddr.sin_addr.s_addr = ahost;
-
+#ifdef STRUCT_SOCKADDR_HAS_SA_LEN
+    taddr.sin_len = sizeof(struct sockaddr_in);
+#endif
 
     /* We need to trim the niovecs. */
     nbytes = apacket->length;
@@ -1469,14 +1471,15 @@ static void rxi_SendDebugPacket(struct rx_packet *apacket, osi_socket asocket,
 }
 
 /* Send the packet to appropriate destination for the specified
- * connection.  The header is first encoded and placed in the packet.
+ * call.  The header is first encoded and placed in the packet.
  */
-void rxi_SendPacket(struct rx_connection * conn, struct rx_packet *p,
-		    int istack)
+void rxi_SendPacket(struct rx_call * call, struct rx_connection * conn,
+		    struct rx_packet *p, int istack)
 {
 #if defined(KERNEL)
     int waslocked;
 #endif
+    int code;
     struct sockaddr_in addr;
     register struct rx_peer *peer = conn->peer;
     osi_socket socket;
@@ -1548,14 +1551,24 @@ void rxi_SendPacket(struct rx_connection * conn, struct rx_packet *p,
 	waslocked = ISAFS_GLOCK();
 	if (waslocked) AFS_GUNLOCK();
 #endif
-	if (osi_NetSend(socket, &addr, p->wirevec, p->niovecs, 
-			p->length+RX_HEADER_SIZE, istack)){
+	if ((code = osi_NetSend(socket, &addr, p->wirevec, p->niovecs, 
+				p->length+RX_HEADER_SIZE, istack)) != 0) {
 	  /* send failed, so let's hurry up the resend, eh? */
 	  MUTEX_ENTER(&rx_stats_mutex);
 	  rx_stats.netSendFailures++;	   
 	  MUTEX_EXIT(&rx_stats_mutex);
 	  p->retryTime = p->timeSent;  /* resend it very soon */
 	  clock_Addmsec(&(p->retryTime), 10 + (((afs_uint32) p->backoff) << 8));
+
+#if defined(KERNEL) && defined(AFS_LINUX20_ENV)
+	  /* Linux is nice -- it can tell us right away that we cannot
+	   * reach this recipient by returning an ENETUNREACH error
+	   * code.  So, when this happens let's "down" the host NOW so
+	   * we don't sit around waiting for this host to timeout later.
+	   */
+	  if (call && code == -ENETUNREACH)
+	    call->lastReceiveTime = 0;
+#endif
 	}
 #ifdef KERNEL
 	if (waslocked) AFS_GLOCK();
@@ -1580,10 +1593,8 @@ void rxi_SendPacket(struct rx_connection * conn, struct rx_packet *p,
 /* Send a list of packets to appropriate destination for the specified
  * connection.  The headers are first encoded and placed in the packets.
  */
-void rxi_SendPacketList(struct rx_connection * conn,
-			struct rx_packet **list,
-			int len,
-			int istack)
+void rxi_SendPacketList(struct rx_call * call, struct rx_connection * conn,
+			struct rx_packet **list, int len, int istack)
 {
 #if     defined(AFS_SUN5_ENV) && defined(KERNEL)
     int waslocked;
@@ -1593,7 +1604,7 @@ void rxi_SendPacketList(struct rx_connection * conn,
     osi_socket socket;
     struct rx_packet *p = NULL;
     struct iovec wirevec[RX_MAXIOVECS];
-    int i, length;
+    int i, length, code;
     afs_uint32 serial;
     afs_uint32 temp;
     struct rx_jumboHeader *jp;
@@ -1713,7 +1724,7 @@ void rxi_SendPacketList(struct rx_connection * conn,
 	waslocked = ISAFS_GLOCK();
 	if (!istack && waslocked) AFS_GUNLOCK();
 #endif
-	if (osi_NetSend(socket, &addr, &wirevec[0], len+1, length, istack)){
+	if ((code = osi_NetSend(socket, &addr, &wirevec[0], len+1, length, istack)) != 0){
 	  /* send failed, so let's hurry up the resend, eh? */
 	  MUTEX_ENTER(&rx_stats_mutex);
 	  rx_stats.netSendFailures++;	   
@@ -1723,6 +1734,15 @@ void rxi_SendPacketList(struct rx_connection * conn,
 	    p->retryTime = p->timeSent;  /* resend it very soon */
 	    clock_Addmsec(&(p->retryTime), 10 + (((afs_uint32) p->backoff) << 8));
 	  }
+#if defined(KERNEL) && defined(AFS_LINUX20_ENV)
+	  /* Linux is nice -- it can tell us right away that we cannot
+	   * reach this recipient by returning an ENETUNREACH error
+	   * code.  So, when this happens let's "down" the host NOW so
+	   * we don't sit around waiting for this host to timeout later.
+	   */
+	  if (call && code == -ENETUNREACH)
+	    call->lastReceiveTime = 0;
+#endif
 	}
 #if	defined(AFS_SUN5_ENV) && defined(KERNEL)
 	if (!istack && waslocked) AFS_GLOCK();
@@ -1814,7 +1834,7 @@ rxi_SendSpecial(call, conn, optionalPacket, type, data, nbytes, istack)
     }
 
     if (call) rxi_Send(call, p, istack);
-    else rxi_SendPacket(conn, p, istack);
+    else rxi_SendPacket((struct rx_call *)0, conn, p, istack);
     if (saven) {  /* means we truncated the packet above.  We probably don't  */
       /* really need to do this, but it seems safer this way, given that  */
       /* sneaky optionalPacket... */
@@ -1854,18 +1874,29 @@ register struct rx_packet *p;
     register afs_uint32 *buf = (afs_uint32*)(p->wirevec[0].iov_base);      /* MTUXXX */
     afs_uint32 temp;
 
-    p->header.epoch = ntohl(*buf++);
-    p->header.cid = ntohl(*buf++);
-    p->header.callNumber = ntohl(*buf++);
-    p->header.seq = ntohl(*buf++);
-    p->header.serial = ntohl(*buf++);
-    temp = ntohl(*buf++);
+    p->header.epoch = ntohl(*buf);
+    buf++;
+    p->header.cid = ntohl(*buf);
+    buf++;
+    p->header.callNumber = ntohl(*buf);
+    buf++;
+    p->header.seq = ntohl(*buf);
+    buf++;
+    p->header.serial = ntohl(*buf);
+    buf++;
+
+    temp = ntohl(*buf);
+    buf++;
+
     /* C will truncate byte fields to bytes for me */
     p->header.type = temp>>24;
     p->header.flags = temp>>16;
     p->header.userStatus = temp>>8;
     p->header.securityIndex = temp>>0;
-    temp = ntohl(*buf++);
+
+    temp = ntohl(*buf);
+    buf++;
+
     p->header.serviceId = (temp&0xffff);
     p->header.spare = temp>>16;
     /* Note: top 16 bits of this last word are the security checksum */
