@@ -32,19 +32,21 @@
  * rpc_scan.c, Scanner for the RPC protocol compiler 
  * Copyright (C) 1987, Sun Microsystems, Inc. 
  */
+
+/* Portions Copyright (c) 2003 Apple Computer, Inc. */
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rxgen/rpc_scan.c,v 1.1.1.4 2001/07/14 22:23:51 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rxgen/rpc_scan.c,v 1.1.1.6 2004/01/10 20:57:25 hartmans Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#else
 #ifdef HAVE_STRING_H
 #include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
 #endif
 #endif
 #include "rpc_scan.h"
@@ -208,6 +210,10 @@ get_token(tokp)
 				if (commenting) {
 					break;
 				} else if (cppline(curline)) {
+#if defined(AFS_DARWIN_ENV)
+					if (strncmp(curline, "#pragma", 7) == 0)
+						continue;
+#endif /* defined(AFS_DARWIN_ENV) */
 					docppline(curline, &linenum, 
 						  &infilename);
 				} else if (directive(curline)) {
