@@ -7,9 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/sys/iinc.c,v 1.1.1.4 2001/07/14 22:24:02 hartmans Exp $");
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/file.h>
