@@ -15,7 +15,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/sys/rmtsysc.c,v 1.1.1.6 2001/07/14 22:24:04 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/sys/rmtsysc.c,v 1.1.1.8 2003/07/30 17:13:02 hartmans Exp $");
 
 #include <errno.h>
 #include <limits.h>
@@ -33,6 +33,9 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/sys/rmtsysc.c,v
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include <rx/xdr.h>
 #include "rmtsys.h"
 
@@ -107,7 +110,7 @@ char *syscall;
 	printf("host %s not found; %s call aborted\n", afs_server, syscall);
 	return 0;
     }
-    bcopy(th->h_addr, &hostAddr, sizeof(hostAddr));
+    memcpy(&hostAddr, th->h_addr, sizeof(hostAddr));
     return hostAddr;
 }
 
@@ -229,7 +232,7 @@ struct ViceIoctl *data;
     if (!(inbuffer = (char *)malloc(ins)))
 	 return	(-1);	    /* helpless here */
     if (data->in_size)
-	bcopy(data->in, inbuffer, data->in_size);
+	memcpy(inbuffer, data->in, data->in_size);
     InData.rmtbulk_len = data->in_size;
     InData.rmtbulk_val = inbuffer;
     inparam_conversion(cmd, InData.rmtbulk_val, 0);
