@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ubik/beacon.c,v 1.1.1.9 2001/09/20 06:16:28 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/ubik/beacon.c,v 1.1.1.13 2004/01/10 20:57:50 hartmans Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -25,6 +25,13 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ubik/beacon.c,v
 #endif
 #include <errno.h>
 #include <lock.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <rx/rx_multi.h>
@@ -50,6 +57,7 @@ int (*ubik_CRXSecurityProc)();
 char *ubik_CRXSecurityRock;
 afs_int32 ubikSecIndex;
 struct rx_securityClass     *ubikSecClass;
+static verifyInterfaceAddress();
 
 
 /* Module responsible for both deciding if we're currently the sync site,
@@ -170,7 +178,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
     struct ubik_server *magicServer;
 
     /* verify that the addresses passed in are correct */
-    if (code = verifyInterfaceAddress(&ame, info, aservers))
+    if ((code = verifyInterfaceAddress(&ame, info, aservers)))
 	return code;
 
     /* get the security index to use, if we can */
@@ -229,7 +237,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
 	}
     } else {
         i = 0;
-        while (servAddr = *aservers++) {
+        while ((servAddr = *aservers++)) {
 	    if (i >= MAXSERVERS) return UNHOSTS;	    /* too many hosts */
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
 	    memset(ts, 0, sizeof(struct ubik_server));
@@ -359,7 +367,7 @@ ubeacon_Interact() {
 
 	/* now analyze return codes, counting up our votes */
 	yesVotes = 0;		    /* count how many to ensure we have quorum */
-	oldestYesVote =	0x3fffffff; /* time quorum expires */
+	oldestYesVote =	0x7fffffff; /* time quorum expires */
 	syncsite= ubeacon_AmSyncSite();
 	startTime = FT_ApproxTime();
 	/*
@@ -447,7 +455,8 @@ static verifyInterfaceAddress(ame, info, aservers)
     afs_uint32 aservers[]; 	/* list of all possible server addresses */
 {
     afs_uint32	myAddr[UBIK_MAX_INTERFACE_ADDR], *servList, tmpAddr;
-    int 	count, found, i, j, totalServers, start, end;
+    afs_uint32  myAddr2[UBIK_MAX_INTERFACE_ADDR];
+    int tcount,	count, found, i, j, totalServers, start, end, usednetfiles = 0;
 
     if (info)
         totalServers = info->numServers;
@@ -476,6 +485,7 @@ static verifyInterfaceAddress(ame, info, aservers)
 	ubik_print("Aborting..\n");
 	return UBADHOST;
       }
+      usednetfiles++;
     }
     else {
       /* get all my interface addresses in net byte order */
@@ -503,7 +513,32 @@ static verifyInterfaceAddress(ame, info, aservers)
     {
 	ubik_print("ubik: primary address %s does not exist\n",
 			afs_inet_ntoa(*ame));
-	return UBADHOST;
+	/* if we had the result of rx_getAllAddr already, avoid subverting
+	   the "is gethostbyname(gethostname()) us" check. If we're
+	   using NetInfo/NetRestrict, we assume they have enough clue
+	   to avoid that big hole in their foot from the loaded gun. */
+	if (usednetfiles) {
+	    /* take the address we did get, then see if ame was masked */
+	    *ame=myAddr[0];
+	    tcount = rx_getAllAddr(myAddr2, UBIK_MAX_INTERFACE_ADDR); 
+	    if ( tcount <= 0 )           /* no address found */
+	    {
+		ubik_print("ubik: No network addresses found, aborting..");
+		return UBADHOST;
+	    }
+	    
+	    /* verify that the My-address passed in by ubik is correct */
+	    for ( j=0, found = 0; j < tcount; j++)
+	    {
+		if ( *ame == myAddr2[j] ) /* both in net byte order */
+		{
+		    found = 1;
+		    break;
+		}
+	    }
+	}
+	if ( !found )
+	    return UBADHOST;
     }
 
     /* if any of my addresses are there in serverList, then
