@@ -18,19 +18,17 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/uss/uss_ptserver.c,v 1.1.1.4 2001/07/14 22:24:16 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/uss/uss_ptserver.c,v 1.1.1.6 2003/04/13 19:08:03 hartmans Exp $");
 
 #include "uss_ptserver.h"	/*Module interface*/
 #include <afs/ptclient.h>	/*Protection Server client interface*/
 #include <afs/pterror.h>	/*Protection Server error codes*/
 #include <afs/com_err.h>	/*Error code xlation*/
 
-extern int errno;
 
 #undef USS_PTSERVER_DB
 
 extern int line;
-extern char *rindex();
 
 
 /*
