@@ -7,6 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/util/test/dtest.c,v 1.1.1.4 2001/07/14 22:24:33 hartmans Exp $");
+
 #include "ktime.h"
 
 main(argc, argv)
