@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/viced/host.c,v 1.1.1.9 2002/05/11 00:03:28 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/viced/host.c,v 1.1.1.14 2003/07/30 17:13:36 hartmans Exp $");
 
 #include <stdio.h>
 #include <errno.h>
@@ -534,11 +534,14 @@ void h_flushhostcps(hostaddr, hport)
     register afs_uint32  hostaddr, hport;  /* net byte order */
 {
     register struct host *host;
+    int held = 0;
     
     H_LOCK
-    host = h_Lookup_r(hostaddr, hport);
+    host = h_Lookup_r(hostaddr, hport, &held);
     if (host) {
-      host->hcpsfailed = 1;
+	host->hcpsfailed = 1;
+	if (!held)
+	    h_Release_r(host);
     }
     H_UNLOCK
 
@@ -597,7 +600,7 @@ struct host *h_Alloc_r(r_con)
 	if (serverentry)
 	    consolePort = serverentry->s_port;
 	else
-	    consolePort = DEF_ROPCONS;	/* Use a default */
+	    consolePort = htons(DEF_ROPCONS);	/* Use a default */
     }
     if (host->port == consolePort) host->Console = 1;
     /* Make a callback channel even for the console, on the off chance that it
@@ -619,6 +622,8 @@ struct host *h_Alloc_r(r_con)
     /*host->hcpsfailed = 0; 	/* save cycles */
     /* h_gethostcps(host);      do this under host lock */
     host->FirstClient = 0;      
+    h_Hold_r(host);
+    h_Lock_r(host);
     h_InsertList_r(host);	/* update global host List */
 #if FS_STATS_DETAILED
     /*
@@ -635,18 +640,21 @@ struct host *h_Alloc_r(r_con)
 
 
 /* Lookup a host given an IP address and UDP port number. */
-struct host *h_Lookup(hostaddr, hport)
+struct host *h_Lookup(hostaddr, hport, heldp)
     afs_uint32 hostaddr, hport;     /* network byte order */
+    int *heldp;
 {
     struct host *retVal;
     H_LOCK
-    retVal = h_Lookup_r(hostaddr, hport);
+    retVal = h_Lookup_r(hostaddr, hport, heldp);
     H_UNLOCK
     return retVal;
 }
 
-struct host *h_Lookup_r(hostaddr, hport)
+/* Note: host should be released by caller if 0 == *heldp and non-null */
+struct host *h_Lookup_r(hostaddr, hport, heldp)
     afs_uint32 hostaddr, hport;     /* network byte order */
+    int *heldp;
 {
     register afs_int32 now;
     register struct host *host=0;
@@ -654,17 +662,30 @@ struct host *h_Lookup_r(hostaddr, hport)
     register index = h_HashIndex(hostaddr);
     extern int hostaclRefresh;
 
+restart:
     for (chain=hostHashTable[index]; chain; chain=chain->next) {
 	host = chain->hostPtr;
 	assert(host);
         if (!(host->hostFlags & HOSTDELETED) && chain->addr == hostaddr
 	    && host->port == hport) {
+	    *heldp = h_Held_r(host);
+	    if (!*heldp)
+		h_Hold_r(host);
+	    h_Lock_r(host);
+	    if (host->hostFlags & HOSTDELETED) {
+		h_Unlock_r(host);
+		if (!*heldp)
+		    h_Release_r(host);
+		goto restart;
+	    }
+	    h_Unlock_r(host);
             now = FT_ApproxTime();		/* always evaluate "now" */
 	    if (host->hcpsfailed || (host->cpsCall+hostaclRefresh < now )) {
 		/*
-		 * Every hostaclRefresh period (def 2 hrs) get the new membership list for the host.
-		 * Note this could be the first time that the host is added to a group.
-		 * Also here we also retry on previous legitimate hcps failures
+		 * Every hostaclRefresh period (def 2 hrs) get the new
+		 * membership list for the host.  Note this could be the
+		 * first time that the host is added to a group.  Also
+		 * here we also retry on previous legitimate hcps failures.
 		 */
 		h_gethostcps_r(host,now);
 	    }
@@ -895,16 +916,19 @@ h_Enumerate(proc, param)
     free((void *)held);
 } /*h_Enumerate*/
 
-/* h_Enumerate_r: Calls (*proc)(host, held, param) for at least each host in
- * the at the start of the enumeration (perhaps more).  Hosts may be deleted
- * (have delete flag set); ditto for clients.  (*proc) is always called with
+/* h_Enumerate_r (revised):
+ * Calls (*proc)(host, held, param) for each host in hostList, starting
+ * at enumstart
+ * Hosts may be deleted (have delete flag set); ditto for clients.
+ * (*proc) is always called with
  * host h_held() and the global host lock (H_LOCK) locked.The hold state of the
  * host with respect to this lwp is passed to (*proc) as the param held.
  * The proc should return 0 if the host should be released, 1 if it should
  * be held after enumeration.
  */
-h_Enumerate_r(proc, param)
+h_Enumerate_r(proc, enumstart, param)
     int (*proc)();
+    struct host* enumstart;
     char *param;
 
 {
@@ -914,15 +938,14 @@ h_Enumerate_r(proc, param)
     if (hostCount == 0) {
 	return;
     }
-    for (host = hostList ; host ; host = host->next) {
+    for (host = enumstart ; host ; host = host->next) {
 	if (!(held = h_Held_r(host)))
 	    h_Hold_r(host);
 	held = (*proc)(host, held, param);
 	if (!held)
 	    h_Release_r(host);/* this might free up the host */
     }
-} /*h_Enumerate*/
-
+} /*h_Enumerate_r*/
 
 /* Host is returned held */
 struct host *h_GetHost_r(tcon)
@@ -935,7 +958,6 @@ struct host *h_GetHost_r(tcon)
     int held;
     struct interfaceAddr interf;
     int interfValid = 0;
-    afs_int32	buffer[AFS_MAX_INTERFACE_ADDR];
     struct Identity *identP = NULL;
     afs_int32 haddr;
     afs_int32 hport;
@@ -946,15 +968,13 @@ struct host *h_GetHost_r(tcon)
     hport = rxr_PortOf(tcon);
 retry:
     code = 0;
+    host = h_Lookup_r(haddr, hport, &held);
     identP = (struct Identity *)rx_GetSpecific(tcon, rxcon_ident_key);
-    host = h_Lookup_r(haddr, hport);
     if (host && !identP && !(host->Console&1)) {
 	/* This is a new connection, and we already have a host
 	 * structure for this address. Verify that the identity
 	 * of the caller matches the identity in the host structure.
 	 */
-	if (!(held = h_Held_r(host)))
-		h_Hold_r(host);
 	h_Lock_r(host);
 	if ( !(host->hostFlags & ALTADDR) )
 	{
@@ -962,7 +982,7 @@ retry:
 		h_Unlock_r(host);
 		if ( !held) h_Release_r(host);
 		ViceLog(125, ("Host %s:%d starting h_Lookup again\n",
-			     afs_inet_ntoa_r(host->host, hoststr), host->port));
+			     afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port)));
 		goto retry;
 	}
 	host->hostFlags &= ~ALTADDR;
@@ -970,7 +990,7 @@ retry:
 	code = RXAFSCB_WhoAreYou(host->callback_rxcon, &interf);
 	H_LOCK
 	if ( code == RXGEN_OPCODE ) {
-		identP = (struct Identity *)malloc(1);
+		identP = (struct Identity *)malloc(sizeof(struct Identity));
 		identP->valid = 0;
 		rx_SetSpecific(tcon, rxcon_ident_key, identP);
 		/* The host on this connection was unable to respond to 
@@ -980,7 +1000,7 @@ retry:
 		if (host->interface) {
 		    ViceLog(0,
 			    ("Host %s:%d used to support WhoAreYou, deleting.\n",
-			    afs_inet_ntoa_r(host->host, hoststr), host->port));
+			    afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port)));
 		    host->hostFlags |= HOSTDELETED;
 		    h_Unlock_r(host);
 		    if (!held) h_Release_r(host);
@@ -1016,18 +1036,16 @@ retry:
 	host->hostFlags |= ALTADDR;
 	h_Unlock_r(host);
     } else if (host) {
-	if (!(held = h_Held_r(host)))
-		h_Hold_r(host);
 	if ( ! (host->hostFlags & ALTADDR) ) 
 	{
         	/* another thread is doing the initialisation */
 		ViceLog(125, ("Host %s:%d waiting for host-init to complete\n",
-			     afs_inet_ntoa_r(host->host, hoststr), host->port));
+			     afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port)));
 		h_Lock_r(host);
 		h_Unlock_r(host);
 		if ( !held) h_Release_r(host);
 		ViceLog(125, ("Host %s:%d starting h_Lookup again\n",
-			     afs_inet_ntoa_r(host->host, hoststr), host->port));
+			     afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port)));
 		goto retry;
 	}
 	/* We need to check whether the identity in the host structure
@@ -1037,42 +1055,59 @@ retry:
 	  && ( ( !identP->valid && host->interface )
 	    || ( identP->valid && !host->interface )
 	    || ( identP->valid
-	      && !afs_uuid_equal(&identP->uuid, &host->interface->uuid) ) ) ) {
-		/* The host in the cache is not the host for this connection */
-		host->hostFlags |= HOSTDELETED;
-		h_Unlock_r(host);
-		if (!held) h_Release_r(host);
-		ViceLog(0, ("CB: new identity for host %s:%d, deleting\n",
-			   afs_inet_ntoa_r(host->host, hoststr), host->port));
-		goto retry;
+	      && !afs_uuid_equal(&identP->uuid, &host->interface->uuid) ) ) ) 
+	{
+	    char uuid1[128], uuid2[128];
+	    if (identP->valid)
+		afsUUID_to_string(&identP->uuid, uuid1, 127);
+	    if (host->interface)
+		afsUUID_to_string(&host->interface->uuid, uuid2, 127);
+	    ViceLog(0, 
+		    ("CB: new identity for host %s:%d, deleting(%x %x %s %s)\n", 
+		     afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port), 
+		     identP->valid, host->interface, identP->valid ? uuid1 : 
+		     "", host->interface ? uuid2 : ""));
+
+	    /* The host in the cache is not the host for this connection */
+	    host->hostFlags |= HOSTDELETED;
+	    h_Unlock_r(host);
+	    if (!held) h_Release_r(host);
+	    goto retry;
 	}
     } else {
         host = h_Alloc_r(tcon);
-        h_Hold_r(host);
-        h_Lock_r(host);
 	h_gethostcps_r(host,FT_ApproxTime());
         if (!(host->Console&1)) {
-	    if (!identP || !interfValid) {
-		H_UNLOCK
-		code = RXAFSCB_WhoAreYou(host->callback_rxcon, &interf);
-		H_LOCK
-		if ( code == RXGEN_OPCODE ) {
-		    identP = (struct Identity *)malloc(1);
-		    identP->valid = 0;
-		    rx_SetSpecific(tcon, rxcon_ident_key, identP);
-		    ViceLog(25,
-			    ("Host %s:%d does not support WhoAreYou.\n",
-			    afs_inet_ntoa_r(host->host, hoststr), host->port));
-		    code = 0;
-		} else if (code == 0) {
-		    interfValid = 1;
+	    int pident = 0;
+	    H_UNLOCK
+	    code = RXAFSCB_WhoAreYou(host->callback_rxcon, &interf);
+	    H_LOCK
+	    if ( code == RXGEN_OPCODE ) {
+		if (!identP)
 		    identP = (struct Identity *)malloc(sizeof(struct Identity));
-		    identP->valid = 1;
-		    identP->uuid = interf.uuid;
+		else
+		    pident = 1;
+		identP->valid = 0;
+		if (!pident)
 		    rx_SetSpecific(tcon, rxcon_ident_key, identP);
-		    ViceLog(25, ("WhoAreYou success on %s:%d\n",
-				afs_inet_ntoa_r(host->host, hoststr), host->port));
-		}
+		ViceLog(25,
+			("Host %s:%d does not support WhoAreYou.\n",
+			 afs_inet_ntoa_r(host->host, hoststr), 
+			 ntohs(host->port)));
+		code = 0;
+	    } else if (code == 0) {
+		if (!identP)
+		    identP = (struct Identity *)malloc(sizeof(struct Identity));
+		else
+		    pident = 1;
+		identP->valid = 1;
+		interfValid = 1;
+		identP->uuid = interf.uuid;
+		if (!pident)
+		    rx_SetSpecific(tcon, rxcon_ident_key, identP);
+		ViceLog(25, ("WhoAreYou success on %s:%d\n",
+			     afs_inet_ntoa_r(host->host, hoststr), 
+			     ntohs(host->port)));
 	    }
 	    if (code == 0 && !identP->valid) {
 	 	H_UNLOCK
@@ -1088,8 +1123,8 @@ retry:
 			h_Hold_r(oldHost);
 		    h_Lock_r(oldHost);
 		    ViceLog(25, ("CB: new addr %s:%d for old host %s:%d\n",
-				afs_inet_ntoa_r(host->host, hoststr), host->port,
-				afs_inet_ntoa_r(oldHost->host, hoststr2), oldHost->port));
+				afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port),
+				afs_inet_ntoa_r(oldHost->host, hoststr2), ntohs(oldHost->port)));
 		    host->hostFlags |= HOSTDELETED;
 		    h_Unlock_r(host);
 		    h_Release_r(host);
@@ -1104,7 +1139,7 @@ retry:
 		    H_LOCK
 		    if (code == 0) {
 			ViceLog(25, ("InitCallBackState3 success on %s:%d\n",
-				    afs_inet_ntoa_r(host->host, hoststr), host->port));
+				    afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port)));
 			assert(interfValid == 1);
 			initInterfaceAddr_r(host, &interf);
 		    }
@@ -1182,7 +1217,7 @@ static MapName_r(aname, acell, aval)
 		return 0;
 	    }		    
 	    foreign = 1;  /* attempt cross-cell authentication */
-	    tname = (char *) malloc(anamelen+cnamelen+2);
+	    tname = (char *) malloc(PR_MAXNAMELEN);
 	    strcpy(tname, aname);
 	    tname[anamelen] = '@';
 	    strcpy(tname+anamelen+1, acell);
@@ -1397,7 +1432,7 @@ ticket name length != 64
 	    ViceLog(0, ("pr_GetCPS failed(%d) for user %d, host %s:%d\n",
 		       code, viceid,
 		       afs_inet_ntoa_r(client->host->host, hoststr),
-		       client->host->port));
+		       ntohs(client->host->port)));
 
 	    /* Although ubik_Call (called by pr_GetCPS) traverses thru
 	     * all protection servers and reevaluates things if no
@@ -1466,15 +1501,35 @@ int GetClient(tcon, cp)
     H_LOCK
 
     *cp = client = (struct client *) rx_GetSpecific(tcon, rxcon_client_key);
-    /* XXXX debug */
-    assert(client && client->tcon && rxr_CidOf(client->tcon) == client->sid);
+    if (client == NULL || client->tcon == NULL) {
+	ViceLog(0, ("GetClient: no client in conn %x (host %x), VBUSYING\n", 
+		    tcon, rx_HostOf(rx_PeerOf(tcon))));
+	H_UNLOCK
+	return VBUSY;
+    }
+    if (rxr_CidOf(client->tcon) != client->sid) {
+	ViceLog(0, ("GetClient: tcon %x tcon sid %d client sid %d\n",
+		    client->tcon, rxr_CidOf(client->tcon),
+		    client->sid));
+	H_UNLOCK
+	return VBUSY;
+    }
+    if (!(client && client->tcon && rxr_CidOf(client->tcon) == client->sid)) {
+	if (!client)
+	    ViceLog(0, ("GetClient: no client in conn %x\n", tcon));
+	else
+	    ViceLog(0, ("GetClient: tcon %x tcon sid %d client sid %d\n", 
+			client->tcon, client->tcon ? rxr_CidOf(client->tcon)
+			: -1, client->sid));
+	assert(0);
+    }
     if (client &&
 	client->LastCall > client->expTime && client->expTime) {
 	char hoststr[16];
 	ViceLog(1, ("Token for %s at %s:%d expired %d\n",
 		h_UserName(client),
 		afs_inet_ntoa_r(client->host->host, hoststr),
-		client->host->port, client->expTime));
+		ntohs(client->host->port), client->expTime));
 	H_UNLOCK
 	return VICETOKENDEAD;
     }
@@ -1539,7 +1594,7 @@ static int h_PrintClient(host, held, file)
 	return held;
     }
     sprintf(tmpStr,"Host %s:%d down = %d, LastCall %s",
-	    afs_inet_ntoa_r(host->host, hoststr), host->port,
+	    afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port),
 	    (host->hostFlags & VENUSDOWN),
 	    afs_ctime((time_t *)&host->LastCall, tbuffer, sizeof(tbuffer)));
     STREAM_WRITE(tmpStr, strlen(tmpStr), 1, file);
@@ -1618,7 +1673,7 @@ static int h_DumpHost(host, held, file)
 
     H_LOCK
     sprintf(tmpStr, "ip:%x port:%d hidx:%d cbid:%d lock:%x last:%u active:%u down:%d del:%d cons:%d cldel:%d\n\t hpfailed:%d hcpsCall:%u hcps [",
-	    host->host, host->port, host->index, host->cblist,
+	    host->host, ntohs(host->port), host->index, host->cblist,
 	    CheckLock(&host->lock), host->LastCall, host->ActiveCall, 
 	    (host->hostFlags & VENUSDOWN), host->hostFlags&HOSTDELETED, 
 	    host->Console, host->hostFlags & CLIENTDELETED, 
@@ -1917,7 +1972,6 @@ int CheckHost(host, held)
 
 {
     register struct client *client;
-    struct interfaceAddr interf;
     int code;
 
     /* Host is held by h_Enumerate */
@@ -2042,7 +2096,7 @@ struct interfaceAddr *interf;
 {
 	int i, j;
 	int number, count;
-	afs_int32		myPort, myHost;
+	afs_int32		myHost;
 	int found;
 	struct Interface *interface;
 
@@ -2053,11 +2107,10 @@ struct interfaceAddr *interf;
 		host->host, interf->numberOfInterfaces));
 
 	number = interf->numberOfInterfaces;
-	myPort   = host->port;
-	myHost   = host->host; /* current interface address */
+	myHost = host->host; /* current interface address */
 
 	/* validation checks */
-	if ( number < 0 )
+	if ( number < 0 || number > AFS_MAX_INTERFACE_ADDR )
         {
 		ViceLog(0,("Number of alternate addresses returned is %d\n",
 			 number));
