@@ -16,7 +16,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/viced/physio.c,v 1.1.1.4 2001/07/14 22:24:47 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/viced/physio.c,v 1.1.1.6 2002/05/11 00:03:29 hartmans Exp $");
 
 #include <stdio.h>
 #include <errno.h>
@@ -59,7 +59,7 @@ char	      *	data;
     if (fdP == NULL) {
 	code = errno;
         ViceLog (0,
-		 ("ReallyRead(): open failed device %X inode %X errno %d\n",
+		 ("ReallyRead(): open failed device %X inode %s errno %d\n",
 		  file->dirh_handle->ih_dev,
 		  PrintInode(NULL, file->dirh_handle->ih_ino), code));
 	return code;
@@ -67,7 +67,7 @@ char	      *	data;
     if (FDH_SEEK(fdP, block * PAGESIZE, SEEK_SET) < 0) {
 	code = errno;
         ViceLog (0,
-		 ("ReallyRead(): lseek failed device %X inode %X errno %d\n",
+		 ("ReallyRead(): lseek failed device %X inode %s errno %d\n",
 		  file->dirh_handle->ih_dev,
 		  PrintInode(NULL, file->dirh_handle->ih_ino), code));
 	FDH_REALLYCLOSE(fdP);
@@ -80,7 +80,7 @@ char	      *	data;
 	else
 	    code = EIO;
         ViceLog (0,
-		 ("ReallyRead(): read failed device %X inode %X errno %d\n",
+		 ("ReallyRead(): read failed device %X inode %s errno %d\n",
 		  file->dirh_handle->ih_dev,
 		  PrintInode(NULL, file->dirh_handle->ih_ino), code));
 	FDH_REALLYCLOSE(fdP);
@@ -103,7 +103,7 @@ char	      *	data;
     fdP = IH_OPEN(file->dirh_handle);
     if (fdP == NULL) {
         ViceLog (0,
-		 ("ReallyWrite(): open failed device %X inode %X errno %d\n",
+		 ("ReallyWrite(): open failed device %X inode %s errno %d\n",
 		  file->dirh_handle->ih_dev,
 		  PrintInode(NULL, file->dirh_handle->ih_ino), errno));
 	lpErrno = errno;
@@ -111,7 +111,7 @@ char	      *	data;
     }
     if (FDH_SEEK(fdP, block * PAGESIZE, SEEK_SET) < 0) {
         ViceLog (0,
-		 ("ReallyWrite(): lseek failed device %X inode %X errno %d\n",
+		 ("ReallyWrite(): lseek failed device %X inode %s errno %d\n",
 		  file->dirh_handle->ih_dev,
 		  PrintInode(NULL, file->dirh_handle->ih_ino), errno));
 	lpErrno = errno;
@@ -120,7 +120,7 @@ char	      *	data;
     }
     if ((count = FDH_WRITE(fdP, data, PAGESIZE)) != PAGESIZE) {
         ViceLog (0,
-		 ("ReallyWrite(): write failed device %X inode %X errno %d\n",
+		 ("ReallyWrite(): write failed device %X inode %s errno %d\n",
 		  file->dirh_handle->ih_dev,
 		  PrintInode(NULL, file->dirh_handle->ih_ino), errno));
 	lpCount = count;
@@ -154,14 +154,14 @@ DirHandle     *	file;
 
 {
     IH_RELEASE(file->dirh_handle);
-    bzero((char *)file, sizeof(DirHandle));
+    memset((char *)file, 0, sizeof(DirHandle));
 }
 
 FidZero (file)
 DirHandle     *	file;
 
 {
-    bzero((char *)file, sizeof(DirHandle));
+    memset((char *)file, 0, sizeof(DirHandle));
 }
 
 FidEq (afile, bfile)
