@@ -19,7 +19,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/viced/viced.c,v 1.1.1.7 2001/09/11 14:35:36 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/viced/viced.c,v 1.1.1.12 2004/01/10 20:58:04 hartmans Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,11 +36,11 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/viced/viced.c,v
 #include <sys/file.h>
 #include <netinet/in.h>
 #include <netdb.h>
-#include <sys/resource.h>
 #include <unistd.h>	/* sysconf() */
 #ifndef ITIMER_REAL
 #include <sys/time.h>
 #endif /* ITIMER_REAL */
+#include <sys/resource.h>
 #endif /* AFS_NT40_ENV */
 #include <afs/stds.h>
 #undef SHARED
@@ -76,6 +76,11 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/viced/viced.c,v
 #endif
 #include "viced.h"
 #include "host.h"
+#ifndef AFS_NT40_ENV
+#ifdef AFS_PTHREAD_ENV
+#include "softsig.h"
+#endif
+#endif
 #if defined(AFS_SGI_ENV)
 #include "sys/schedctl.h"
 #include "sys/lock.h"
@@ -128,6 +133,7 @@ struct afs_PerfStats afs_perfstats;
 extern	int     LogLevel;
 extern	int	Statistics;
 
+int     busyonrst = 1;
 int     timeout = 30;
 int 	SawSpare;
 int 	SawPctSpare;
@@ -203,7 +209,7 @@ static CheckDescriptors()
 #ifdef AFS_PTHREAD_ENV
 void CheckSignal_Signal(x)       {CheckSignal(0);}
 void ShutDown_Signal(x)          {ShutDown(0);}
-void CheckDescriptors_Signal(x)  {CheckDescriptors(0);}
+void CheckDescriptors_Signal(x)  {CheckDescriptors();}
 #else /* AFS_PTHREAD_ENV */
 void CheckSignal_Signal(x)       {IOMGR_SoftSig(CheckSignal, 0);}
 void ShutDown_Signal(x)          {IOMGR_SoftSig(ShutDown, 0);}
@@ -219,22 +225,34 @@ int fs_rxstat_userok(call)
 
 static void ResetCheckSignal(void)
 {
-#ifdef	AFS_HPUX_ENV
-    signal(SIGPOLL, CheckSignal_Signal);
+    int signo;
+
+#if defined(AFS_HPUX_ENV)
+    signo = SIGPOLL;
 #else
-#ifdef AFS_NT40_ENV
-    signal(SIGUSR2, CheckSignal_Signal);
+#if defined(AFS_NT40_ENV)
+    signo = SIGUSR2;
 #else
-    signal(SIGXCPU, CheckSignal_Signal);
+    signo = SIGXCPU;
 #endif
 #endif
+
+#if defined(AFS_PTHREAD_ENV) && !defined(AFS_NT40_ENV)
+    softsig_signal(signo, CheckSignal_Signal);
+#else
+    signal(signo, CheckSignal_Signal);
+#endif
 }
 
 static void ResetCheckDescriptors(void)
 {
 #ifndef AFS_NT40_ENV
+#if defined(AFS_PTHREAD_ENV)
+    softsig_signal(SIGTERM, CheckDescriptors_Signal);
+#else
     signal(SIGTERM, CheckDescriptors_Signal);
 #endif
+#endif
 }
 
 
@@ -299,7 +317,6 @@ main(argc, argv)
 #ifdef AFS_PTHREAD_ENV
     pthread_t parentPid, serverPid;
     pthread_attr_t tattr;
-    AFS_SIGSET_DECL;
 #else /* AFS_PTHREAD_ENV */
     PROCESS parentPid, serverPid;
 #endif /* AFS_PTHREAD_ENV */
@@ -349,6 +366,11 @@ main(argc, argv)
     }
 #endif
     confDir = afsconf_Open(AFSDIR_SERVER_ETC_DIRPATH);
+    if (!confDir) {
+	fprintf(stderr, "Unable to open config directory %s\n",
+		AFSDIR_SERVER_ETC_DIRPATH);
+	exit(-1);
+    }
 
     NewParms(1);
 
@@ -367,6 +389,11 @@ main(argc, argv)
     ViceLog(0, ("File server starting\n"));
 #endif
 
+#if defined(AFS_PTHREAD_ENV) && !defined(AFS_NT40_ENV)
+    /* initialize the pthread soft signal handler thread */
+    softsig_init();
+#endif
+
     /* install signal handlers for controlling the fileserver process */
     ResetCheckSignal();  /* set CheckSignal_Signal() sig handler */
     ResetCheckDescriptors();  /* set CheckDescriptors_Signal() sig handler */
@@ -483,6 +510,7 @@ main(argc, argv)
     rx_SetDestroyConnProc(tservice, (char (*)()) h_FreeConnection);
     rx_SetMinProcs(tservice, 3);
     rx_SetMaxProcs(tservice, lwps);
+    rx_SetCheckReach(tservice, 1);
 
     tservice = rx_NewService(0,  RX_STATS_SERVICE_ID, "rpcstats", sc, 4, RXSTATS_ExecuteRequest);
     if (!tservice) {
@@ -565,11 +593,9 @@ main(argc, argv)
 #ifdef AFS_PTHREAD_ENV
     assert(pthread_attr_init(&tattr) == 0);
     assert(pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED) == 0);
-    /* Block signals in the threads */
-    AFS_SIGSET_CLEAR();
+
     assert(pthread_create(&serverPid, &tattr, (void *)FiveMinuteCheckLWP, &fiveminutes) == 0);
     assert(pthread_create(&serverPid, &tattr, (void *)HostCheckLWP, &fiveminutes) == 0);
-    AFS_SIGSET_RESTORE();
 #else /* AFS_PTHREAD_ENV */
     assert(LWP_CreateProcess(FiveMinuteCheckLWP, stack*1024, LWP_MAX_PRIORITY - 2,
 	    &fiveminutes, "FiveMinuteChecks", &serverPid) == LWP_SUCCESS);
@@ -611,8 +637,14 @@ main(argc, argv)
 		   FS_HostName, hoststr, FS_HostAddr_NBO, FS_HostAddr_HBO));
     }
 
-    /* Install handler to catch the shutdown signal */
-    signal(SIGQUIT, ShutDown_Signal); /* bosserver assumes SIGQUIT shutdown */
+    /* Install handler to catch the shutdown signal;
+     * bosserver assumes SIGQUIT shutdown
+     */
+#if defined(AFS_PTHREAD_ENV) && !defined(AFS_NT40_ENV)
+    softsig_signal(SIGQUIT, ShutDown_Signal);
+#else
+    signal(SIGQUIT, ShutDown_Signal);
+#endif
 
     ViceLog(0,("File Server started %s",
 	       afs_ctime(&tp.tv_sec, tbuffer, sizeof(tbuffer))));
@@ -629,6 +661,18 @@ main(argc, argv)
 }
 
 
+static void setThreadId(char *s)
+{
+#ifdef AFS_PTHREAD_ENV
+    /* set our 'thread-id' so that the host hold table works */
+    MUTEX_ENTER(&rx_stats_mutex);   /* protects rxi_pthread_hinum */ 
+    ++rxi_pthread_hinum;
+    pthread_setspecific(rx_thread_id_key, (void *)rxi_pthread_hinum);
+    MUTEX_EXIT(&rx_stats_mutex);
+    ViceLog(0,("Set thread id %d for '%s'\n", pthread_getspecific(rx_thread_id_key), s));
+#endif
+}
+
 /* This LWP does things roughly every 5 minutes */
 static FiveMinuteCheckLWP()
 
@@ -637,6 +681,7 @@ static FiveMinuteCheckLWP()
     char tbuffer[32];
 
     ViceLog(1, ("Starting five minute check process\n"));
+    setThreadId("FiveMinuteCheckLWP");
     while (1) {
 #ifdef AFS_PTHREAD_ENV
 	sleep(fiveminutes);
@@ -675,6 +720,7 @@ static HostCheckLWP()
 
 {
     ViceLog(1, ("Starting Host check process\n"));
+    setThreadId("HostCheckLWP");
     while(1) {
 #ifdef AFS_PTHREAD_ENV
 	sleep(fiveminutes);
@@ -854,7 +900,7 @@ int dopanic;
     }
 #endif
     DFlush();
-    PrintCounters();
+    if (!dopanic) PrintCounters();
 
     /* do not allows new reqests to be served from now on, all new requests
        are returned with an error code of RX_RESTARTING ( transient failure ) */
@@ -917,6 +963,7 @@ static FlagMsg()
     strcat(buffer, "[-implicit <admin mode bits: rlidwka>] ");
     strcat(buffer, "[-hr <number of hours between refreshing the host cps>] ");
     strcat(buffer, "[-busyat <redirect clients when queue > n>] ");
+    strcat(buffer, "[-nobusy <no VBUSY before a volume is attached>] ");
     strcat(buffer, "[-rxpck <number of rx extra packets>] ");
     strcat(buffer, "[-rxdbg (enable rx debugging)] ");
     strcat(buffer, "[-rxdbge (enable rxevent debugging)] ");
@@ -1146,7 +1193,10 @@ static ParseArgs(argc, argv)
 			   busy_threshold);
 		    Sawbusy = 0;
 		}
-	    }
+	      }
+	    else
+	      if (!strcmp(argv[i], "-nobusy")) 
+		busyonrst=0;
 #ifdef	AFS_AIX32_ENV
 	else
 	    if (!strcmp(argv[i], "-m")) {
