@@ -10,13 +10,20 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vlserver/cnvldb.c,v 1.1.1.4 2001/07/14 22:24:50 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vlserver/cnvldb.c,v 1.1.1.7 2003/07/30 17:13:37 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
 #include <errno.h>
 #include <stdio.h>
 #include <sys/file.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include "cnvldb.h"  /* CHANGEME! */
 #include <netinet/in.h>
 #include <afs/venus.h>
@@ -25,12 +32,11 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vlserver/cnvldb
 #include <afs/fileutil.h>
 
 #include "vlserver.h"
-#include <strings.h>
 
 #define MAXSIZE 2048 /* most I'll get back from PIOCTL */
 #define	BADSERVERID	255	/* XXX */
 
-extern int errno;
+
 extern struct cmd_syndesc *cmd_CreateSyntax();
 static char pn[] = "cnvldb";
 static char tempname[] = "XXnewvldb";
@@ -48,7 +54,7 @@ static char *Parent(apath)
 char *apath; {
     register char *tp;
     strcpy(tspace, apath);
-    tp = rindex(tspace, '/');
+    tp = strrchr(tspace, '/');
     if (tp) {
 	*tp = 0;
     }
@@ -584,7 +590,7 @@ convert_header(ofd, fd, fromv, tov, fromaddr, toaddr)
 
   if (fromv == 1) {
      if (tov == 1) {
-        bcopy (fromaddr, toaddr, sizeof(struct vlheader_1));
+        memcpy(toaddr, fromaddr, sizeof(struct vlheader_1));
 	tvp1 = (struct vlheader_1 *) toaddr;
 	
 	w = write (fd, tvp1, sizeof(struct vlheader_1));
@@ -600,7 +606,7 @@ convert_header(ofd, fd, fromv, tov, fromaddr, toaddr)
      } else if (tov == 2 || tov == 3) {
         tvp1 = (struct vlheader_1 *) fromaddr;
 	tvp2 = (struct vlheader_2 *) toaddr;
-	bzero(tvp2, sizeof(struct vlheader_2));
+	memset(tvp2, 0, sizeof(struct vlheader_2));
 	tvp2->vital_header.vldbversion = htonl(tov);
 	tvp2->vital_header.headersize = htonl(sizeof(struct vlheader_2));
 	diff = ntohl(tvp2->vital_header.headersize) -
@@ -643,7 +649,7 @@ convert_header(ofd, fd, fromv, tov, fromaddr, toaddr)
         return EINVAL;
   } else if (fromv == 2 || fromv == 3 || fromv == 4) {
      if (tov == 2 || tov == 3 || tov == 4) {
-        bcopy (fromaddr, toaddr, sizeof(struct vlheader_2));
+        memcpy(toaddr, fromaddr, sizeof(struct vlheader_2));
 	tvp2 = (struct vlheader_2 *) toaddr;
 	tvp2->vital_header.vldbversion = htonl(tov);
 	w = write (fd, tvp2, sizeof(struct vlheader_2));
@@ -655,7 +661,7 @@ convert_header(ofd, fd, fromv, tov, fromaddr, toaddr)
      } else if (tov == 1) {
         tvp2 = (struct vlheader_2 *) fromaddr;
 	tvp1 = (struct vlheader_1 *) toaddr;
-	bzero(tvp1, sizeof(struct vlheader_1));
+	memset(tvp1, 0, sizeof(struct vlheader_1));
 	tvp1->vital_header.vldbversion = htonl(1);
 	tvp1->vital_header.headersize = htonl(sizeof(struct vlheader_1));
 	diff = ntohl(tvp1->vital_header.headersize) - ntohl(tvp2->vital_header.headersize);
@@ -771,7 +777,7 @@ convert_vlentry(new, fromvers, tovers, oldheader, newheader, vlentryp)
 	vl.nextIdHash[1] = vlentryp->nextIdHash[1];
 	vl.nextIdHash[2] = vlentryp->nextIdHash[2];
 	vl.nextNameHash = vlentryp->nextNameHash;
-	bcopy(vlentryp->name, vl.name, 65);
+	memcpy(vl.name, vlentryp->name, 65);
 	for (i = 0; i < 8; i++) {
 	    vl.serverNumber[i] = vlentryp->serverNumber[i];
 	    vl.serverPartition[i] = vlentryp->serverPartition[i];
@@ -790,7 +796,7 @@ convert_vlentry(new, fromvers, tovers, oldheader, newheader, vlentryp)
 	struct vlentry_2 vl;
 	struct vlentry_3 *xnvlentry = (struct vlentry_3 *) vlentryp;
 
-	bzero((char *)&vl, sizeof (struct vlentry_2));
+	memset((char *)&vl, 0, sizeof (struct vlentry_2));
 	vl.volumeId[0] = xnvlentry->volumeId[0];
 	vl.volumeId[1] = xnvlentry->volumeId[1];
 	vl.volumeId[2] = xnvlentry->volumeId[2];
@@ -804,7 +810,7 @@ convert_vlentry(new, fromvers, tovers, oldheader, newheader, vlentryp)
 	}
 	if (ntohl(xnvlentry->nextNameHash))
 	    vl.nextNameHash = xnvlentry->nextNameHash;
-	bcopy(xnvlentry->name, vl.name, 65);
+	memcpy(vl.name, xnvlentry->name, 65);
 	for (i = 0; i < 8; i++) {
 	    vl.serverNumber[i] = xnvlentry->serverNumber[i];
 	    vl.serverPartition[i] = xnvlentry->serverPartition[i];
@@ -822,7 +828,7 @@ convert_vlentry(new, fromvers, tovers, oldheader, newheader, vlentryp)
 
 	diff = (tovers == 1 ? sizeof(struct vlheader_1) : sizeof(struct vlheader_2))
 	    - (fromvers == 1 ? sizeof(struct vlheader_1) : sizeof(struct vlheader_2));
-	bzero((char *)&vl, sizeof (struct vlentry_1));
+	memset((char *)&vl, 0, sizeof (struct vlentry_1));
 	vl.volumeId[0] = xnvlentry->volumeId[0];
 	vl.volumeId[1] = xnvlentry->volumeId[1];
 	vl.volumeId[2] = xnvlentry->volumeId[2];
@@ -837,7 +843,7 @@ convert_vlentry(new, fromvers, tovers, oldheader, newheader, vlentryp)
 	if (ntohl(xnvlentry->nextNameHash))
 	    vl.nextNameHash = htonl(ntohl(xnvlentry->nextNameHash) + diff);	
 
-	bcopy(xnvlentry->name, vl.name, 65);
+	memcpy(vl.name, xnvlentry->name, 65);
 	for (i = 0; i < 8; i++) {
 	    vl.serverNumber[i] = xnvlentry->serverNumber[i];
 	    vl.serverPartition[i] = xnvlentry->serverPartition[i];
@@ -865,7 +871,7 @@ convert_vlentry(new, fromvers, tovers, oldheader, newheader, vlentryp)
 	 * blocks go away and all vlentries after them move up in the vldb file.
 	 * When this happens, the linked list pointers need to be updated.
 	 */
-	bcopy(vlentryp, &vl, sizeof(vl));
+	memcpy(&vl, vlentryp, sizeof(vl));
 	for (i=0; i<3; i++) {
 	   vl.nextIdHash[i] = Conv4to3(vl.nextIdHash[i]);
 	}
