@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/fs_conv_411.c,v 1.1.1.4 2001/07/14 22:24:53 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/fs_conv_411.c,v 1.1.1.6 2003/04/13 19:08:17 hartmans Exp $");
 
 #if	defined(AFS_DUX40_ENV) || (defined(AFS_SUN_ENV) && !defined(AFS_SUN5_ENV)) || defined(AFS_SUN54_ENV)
 #if defined AFS_DUX40_ENV
@@ -84,7 +84,6 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/fs_conv_411
 int icount=0, iarraysize=0, *iarray;
 
 char *rawname(),  *unrawname(), *vol_DevName(), *blockcheck();
-extern int errno;
 #define ROOTINODE	2	
 int force = 0,  verbose = 0,  unconv = 0;
 
@@ -930,14 +929,13 @@ char *vol_DevName(adev)
     return (char *) 0;	/* failed */
 }
   
-extern char *rindex();
 char *unrawname(name)
 	char *name;
 {
 	char *dp;
 	struct stat stb;
 
-	if ((dp = rindex(name, '/')) == 0)
+	if ((dp = strrchr(name, '/')) == 0)
 		return (name);
 	if (stat(name, &stb) < 0)
 		return (name);
@@ -956,7 +954,7 @@ rawname(name)
 	static char rawbuf[32];
 	char *dp;
 
-	if ((dp = rindex(name, '/')) == 0)
+	if ((dp = strrchr(name, '/')) == 0)
 		return (0);
 	*dp = 0;
 	(void)strcpy(rawbuf, name);
