@@ -38,7 +38,7 @@ static int newVLDB = 1;
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/fssync.c,v 1.1.1.4 2001/07/14 22:24:55 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/fssync.c,v 1.1.1.9 2003/04/13 19:08:17 hartmans Exp $");
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -234,11 +234,15 @@ static int getport(addr)
 {
     int sd;
 
-    bzero(addr, sizeof(*addr));
+    memset(addr, 0, sizeof(*addr));
     assert((sd = socket(AF_INET, SOCK_STREAM, 0)) >= 0);
+#ifdef STRUCT_SOCKADDR_HAS_SA_LEN
+    addr->sin_len = sizeof(struct sockaddr_in);
+#endif
     addr->sin_addr.s_addr = htonl(0x7f000001);
     addr->sin_family = AF_INET; /* was localhost->h_addrtype */
     addr->sin_port = htons(2040);  /* XXXX htons not _really_ neccessary */
+
     return sd;
 }
 
@@ -248,10 +252,23 @@ static void FSYNC_sync() {
     extern VInit;
     int code;
     int numTries;
+#ifdef AFS_PTHREAD_ENV
+    int tid;
+#endif
 
 #ifndef AFS_NT40_ENV
     signal(SIGPIPE, SIG_IGN);
 #endif
+
+#ifdef AFS_PTHREAD_ENV
+    /* set our 'thread-id' so that the host hold table works */ 
+    MUTEX_ENTER(&rx_stats_mutex);   /* protects rxi_pthread_hinum */
+    tid=++rxi_pthread_hinum;
+    MUTEX_EXIT(&rx_stats_mutex);
+    pthread_setspecific(rx_thread_id_key, (void *)tid);
+    Log("Set thread id %d for FSYNC_sync\n", tid);
+#endif /* AFS_PTHREAD_ENV */
+
     while (!VInit) {
       /* Let somebody else run until level > 0.  That doesn't mean that 
        * all volumes have been attached. */
@@ -317,7 +334,7 @@ static void FSYNC_com(fd)
     int fd;
 {
     byte rc = FSYNC_OK;
-    int n, i;
+    int n, i, ack = 1;
     Error error;
     struct command command;
     int leaveonline;
@@ -503,6 +520,12 @@ defect #2080 for details.
 		vp->specialStatus = VMOVED;
 		VPutVolume_r(vp);
 	    }
+#ifdef AFS_NT40_ENV
+	    send(fd, &rc, 1, 0);
+#else
+	    write(fd, &rc, 1);
+#endif
+	    ack = 0;
 	    if (V_BreakVolumeCallbacks) {
 		Log("fssync: volume %u moved to %x; breaking all call backs\n",
 		    command.volume, command.reason);
@@ -515,6 +538,12 @@ defect #2080 for details.
 	    break;
 	case FSYNC_RESTOREVOLUME:
 	    /* if the volume is being restored, break all callbacks on it*/
+#ifdef AFS_NT40_ENV
+	    send(fd, &rc, 1, 0);
+#else
+	    write(fd, &rc, 1);
+#endif
+	    ack = 0;
 	    if (V_BreakVolumeCallbacks) {
 		VOL_UNLOCK
 		VATTACH_UNLOCK
@@ -529,11 +558,13 @@ defect #2080 for details.
     }
     VOL_UNLOCK
     VATTACH_UNLOCK
+    if (ack) {
 #ifdef AFS_NT40_ENV
-    send(fd, &rc, 1, 0);
+	send(fd, &rc, 1, 0);
 #else
-    write(fd, &rc, 1);
+	write(fd, &rc, 1);
 #endif
+    }
 }
 
 static void FSYNC_Drop(fd)
