@@ -5,6 +5,8 @@
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
+ *
+ * Portions Copyright (c) 2003 Apple Computer, Inc.
  */
 
 /*
@@ -18,7 +20,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/partition.c,v 1.1.1.11 2002/05/11 00:03:43 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/partition.c,v 1.1.1.15 2004/01/10 20:58:07 hartmans Exp $");
 
 #include <ctype.h>
 #ifdef AFS_NT40_ENV
@@ -59,7 +61,7 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/partition.c
 #endif
 #endif /* AFS_VFSINCL_ENV */
 #endif	/* AFS_OSF_ENV */
-#include <sys/errno.h>
+#include <errno.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <sys/file.h>
@@ -75,6 +77,9 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/partition.c
 #else
 #if	defined(AFS_SUN_ENV)
 #include <sys/vfs.h>
+#ifndef AFS_SUN5_ENV
+#include <mntent.h>
+#endif
 #endif
 #ifdef AFS_SUN5_ENV
 #include <unistd.h>
@@ -194,9 +199,11 @@ static void VInitPartition_r(char *path, char *devname, Device dev)
     else
 	DiskPartitionList = dp;
     dp->next = 0;
-    strcpy(dp->name, path);
+    dp->name = (char *)malloc(strlen(path) + 1);
+    strncpy(dp->name, path, strlen(path) + 1);
 #if defined(AFS_NAMEI_ENV) && !defined(AFS_NT40_ENV)
     /* Create a lockfile for the partition, of the form /vicepa/Lock/vicepa */
+    dp->devName = (char *)malloc(2 * strlen(path) + 6);
     strcpy(dp->devName, path);
     strcat(dp->devName, "/");
     strcat(dp->devName, "Lock");
@@ -205,7 +212,8 @@ static void VInitPartition_r(char *path, char *devname, Device dev)
     close(open(dp->devName, O_RDWR | O_CREAT, 0600));
     dp->device = volutil_GetPartitionID(path);
 #else
-    strcpy(dp->devName, devname);
+    dp->devName = (char *)malloc(strlen(devname) + 1);
+    strncpy(dp->devName, devname, strlen(devname) + 1);
     dp->device = dev;
 #endif
     dp->lock_fd = -1;
@@ -500,6 +508,7 @@ int VAttachPartitions(void)
 	    continue; /* Ignore any "special" partitions */
 
 #ifdef AFS_AIX42_ENV
+#ifndef AFS_NAMEI_ENV
 	{
 	    struct superblock fs;
 	    /* The Log statements are non-sequiters in the SalvageLog and don't
@@ -516,6 +525,7 @@ int VAttachPartitions(void)
 		continue;
 	    }
 	}
+#endif
 #endif
 
 	/* If we're going to always attach this partition, do it later. */
@@ -803,7 +813,6 @@ void VSetPartitionDiskUsage_r(register struct DiskPartition *dp)
 #else
 void VSetPartitionDiskUsage_r(register struct DiskPartition *dp)
 {
-    extern int errno;
     int fd, totalblks, free, used, availblks, bsize, code;
     int reserved;
 #if AFS_HAVE_STATVFS
@@ -1026,6 +1035,9 @@ void VLockPartition_r(char *name)
     unsigned int	*globalMask;
     int			globalMaskIndex;
 #endif /* defined(AFS_HPUX_ENV) */
+#if defined(AFS_DARWIN_ENV)
+    char lockfile[MAXPATHLEN];
+#endif /* defined(AFS_DARWIN_ENV) */
     
     if (!dp) return;	/* no partition, will fail later */
     if (dp->lock_fd != -1) return;
@@ -1033,13 +1045,21 @@ void VLockPartition_r(char *name)
 #if    defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV)
     partitionName = dp->devName;
     code = O_RDWR;
+#elif defined(AFS_DARWIN_ENV)
+    strlcpy((partitionName = lockfile), dp->name, sizeof(lockfile));
+    strlcat(lockfile, "/.lock.afs", sizeof(lockfile));
+    code = O_RDONLY | O_CREAT;
 #else
     partitionName = dp->name;
     code = O_RDONLY;
 #endif
 
     for (retries=25; retries; retries--) {
+#if defined(AFS_DARWIN_ENV)
+        dp->lock_fd = open(partitionName, code, 0600);
+#else /* ! defined(AFS_DARWIN_ENV) */
         dp->lock_fd = open(partitionName, code);
+#endif /* defined(AFS_DARWIN_ENV) */
         if (dp->lock_fd != -1) break;
         pausing.tv_sec = 0;
         pausing.tv_usec = 500000;
