@@ -17,7 +17,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/physio.c,v 1.1.1.4 2001/07/14 22:24:58 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/physio.c,v 1.1.1.5 2001/09/11 14:35:45 hartmans Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -120,7 +120,7 @@ Inode inode;
 Device device;
 {
     static SalvageCacheCheck = 1;
-    bzero(dir, sizeof(DirHandle));
+    memset(dir, 0, sizeof(DirHandle));
 
     dir->dirh_device = device;
     dir->dirh_volume = volume;
@@ -135,14 +135,14 @@ DirHandle     *	file;
 
 {
     IH_RELEASE(file->dirh_handle);
-    bzero(file, sizeof(DirHandle));
+    memset(file, 0, sizeof(DirHandle));
 }
 
 FidZero (file)
 DirHandle     *	file;
 
 {
-    bzero(file, sizeof(DirHandle));
+    memset(file, 0, sizeof(DirHandle));
 }
 
 FidEq (afile, bfile)
