@@ -16,7 +16,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/purge.c,v 1.1.1.4 2001/07/14 22:24:58 hartmans Exp $");
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/purge.c,v 1.1.1.5 2001/09/11 14:35:46 hartmans Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
@@ -129,7 +129,7 @@ Volume *avp; {
 
     /* next, obliterate the index and fflush (and fsync) it */
     STREAM_SEEK(afile, *aoffset, 0);	/* seek back to start of vnode index region */
-    bzero(buf, sizeof(buf));	/* zero out our proto-vnode */
+    memset(buf, 0, sizeof(buf));	/* zero out our proto-vnode */
     for(i=0;i<nscanned;i++) {
 	if (STREAM_WRITE(buf, vcp->diskSize, 1, afile) != 1)
 	    goto fail;
